@@ -1,9 +1,6 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from multiprocessing.util import register_after_fork
+from typing import Any, Dict, List, Optional
 
 from celery import Celery
 from celery import current_app as celery_current_app
@@ -12,6 +9,7 @@ from celery.app.task import Task
 from celery.loaders.base import BaseLoader
 from celery.task import PeriodicTask as CeleryPeriodicTask
 from celery.utils.imports import symbol_by_name
+from flask import Flask
 from flask import current_app as flask_current_app
 from flask import has_app_context
 from flask.helpers import locked_cached_property
@@ -36,11 +34,11 @@ CELERY_CONF_KEY_PREFIXES = (
 )
 
 
-def is_celery_setting(key):
+def is_celery_setting(key: str) -> bool:
     return any(key.startswith(prefix) for prefix in CELERY_CONF_KEY_PREFIXES)
 
 
-def is_eager():
+def is_eager() -> bool:
     """True when tasks are run eagerly.
 
     As of celery 3.1.17 it seems that when CELERY_ALWAYS_EAGER is set in
@@ -51,7 +49,7 @@ def is_eager():
     ) or celery_current_app.conf.CELERY_ALWAYS_EAGER
 
 
-def safe_session():
+def safe_session() -> Session:
     """Return a sqlalchemy session that can be safely used in a task.
 
     During standard async task processing, there is generally no
@@ -71,21 +69,13 @@ class FlaskLoader(BaseLoader):
     app_context = None
 
     @locked_cached_property
-    def flask_app(self):
+    def flask_app(self) -> Flask:
         if has_app_context():
             return unwrap(flask_current_app)
 
         self.flask_app_factory = symbol_by_name(self.flask_app_factory)
         app = self.flask_app_factory()
 
-        if "sentry" in app.extensions:
-            from raven.contrib.celery import register_signal, register_logger_signal
-
-            client = app.extensions["sentry"].client
-            client.tags["process_type"] = "celery task"
-            register_signal(client)
-            register_logger_signal(client)
-
         register_after_fork(app, self._setup_after_fork)
         return app
 
@@ -95,7 +85,7 @@ class FlaskLoader(BaseLoader):
             engine = db.get_engine(app, bind)
             engine.dispose()
 
-    def read_configuration(self, env=None):
+    def read_configuration(self, env: str = "") -> Dict[str, Any]:
         app = self.flask_app
         app.config.setdefault("CELERY_DEFAULT_EXCHANGE", app.name)
         app.config.setdefault("CELERY_DEFAULT_QUEUE", app.name)
@@ -113,7 +103,7 @@ class FlaskTask(Task):
 
     abstract = True
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args: List, **kwargs: Dict[str, Any]) -> Optional[Any]:
         if is_eager():
             # this is here mainly because flask_sqlalchemy (as of 2.0) will
             # remove session on app context teardown.
@@ -130,10 +120,10 @@ class FlaskTask(Task):
             #                 '_enable_transaction_accounting'
             #
             # FIXME: also test has_app_context()?
-            return super(FlaskTask, self).__call__(*args, **kwargs)
+            return super().__call__(*args, **kwargs)
 
         with self.app.loader.flask_app.app_context():
-            return super(FlaskTask, self).__call__(*args, **kwargs)
+            return super().__call__(*args, **kwargs)
 
 
 class PeriodicTask(FlaskTask, CeleryPeriodicTask):
