@@ -1,37 +1,41 @@
-# coding=utf-8
 """Base class for entities, objects that are managed by the Abilian framwework
 (unlike SQLAlchemy models which are considered lower-level)."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import collections
 import re
 from datetime import datetime
 from inspect import isclass
+from typing import TYPE_CHECKING, Any, Dict, FrozenSet, List, Optional, \
+    Tuple, Type, cast
 
 import sqlalchemy as sa
 from flask import current_app
-from six import text_type, with_metaclass
 from sqlalchemy import event
+from sqlalchemy.engine.base import Connection
 from sqlalchemy.ext.declarative import declared_attr
-from sqlalchemy.orm import Session, mapper
+from sqlalchemy.orm import Mapper, Session, mapper
+from sqlalchemy.orm.unitofwork import UOWTransaction
 from sqlalchemy.schema import Column, ForeignKey
 from sqlalchemy.types import Integer, String, UnicodeText
 
 from .extensions import db
 from .models import BaseMixin
-from .models.base import EDITABLE, SEARCHABLE, SYSTEM, Indexable
+from .models.base import EDITABLE, SEARCHABLE, SYSTEM, Indexable, Model
 from .sqlalchemy import JSONDict
 from .util import friendly_fqcn, memoized, slugify
 
-__all__ = [
+if TYPE_CHECKING:
+    from abilian.core.models.subjects import User
+    from abilian.core.models.tag import Tag
+    from abilian.services.security import Permission
+
+__all__ = (
     "Entity",
     "EntityQuery",
     "Indexable",
     "all_entity_classes",
     "db",
     "ValidationError",
-]
+)
 
 
 #
@@ -41,7 +45,7 @@ class ValidationError(Exception):
     pass
 
 
-def validation_listener(mapper, connection, target):
+def validation_listener(mapper: Mapper, connection: Connection, target: Any) -> None:
     if hasattr(target, "_validate"):
         target._validate()
 
@@ -53,17 +57,17 @@ event.listen(mapper, "before_update", validation_listener)
 #
 # CRUD events. TODO: connect to signals instead?
 #
-def before_insert_listener(mapper, connection, target):
+def before_insert_listener(mapper: Mapper, connection: Connection, target: Any) -> None:
     if hasattr(target, "_before_insert"):
         target._before_insert()
 
 
-def before_update_listener(mapper, connection, target):
+def before_update_listener(mapper: Mapper, connection: Connection, target: Any) -> None:
     if hasattr(target, "_before_update"):
         target._before_update()
 
 
-def before_delete_listener(mapper, connection, target):
+def before_delete_listener(mapper: Mapper, connection: Connection, target: Any) -> None:
     if hasattr(target, "_before_delete"):
         target._before_delete()
 
@@ -73,23 +77,21 @@ event.listen(mapper, "before_update", before_update_listener)
 event.listen(mapper, "before_delete", before_delete_listener)
 
 
-def auto_slug_on_insert(mapper, connection, target):
+def auto_slug_on_insert(mapper: Mapper, connection: Connection, target: Any) -> None:
     """Generate a slug from :prop:`Entity.auto_slug` for new entities, unless
     slug is already set."""
     if target.slug is None and target.name:
         target.slug = target.auto_slug
 
 
-def auto_slug_after_insert(mapper, connection, target):
+def auto_slug_after_insert(mapper: Mapper, connection: Connection, target: Any) -> None:
     """Generate a slug from entity_type and id, unless slug is already set."""
     if target.slug is None:
-        target.slug = "{name}{sep}{id}".format(
-            name=target.entity_class.lower(), sep=target.SLUG_SEPARATOR, id=target.id
-        )
+        target.slug = f"{target.entity_class.lower()}{target.SLUG_SEPARATOR}{target.id}"
 
 
 @event.listens_for(Session, "after_attach")
-def setup_default_permissions(session, instance):
+def setup_default_permissions(session: Session, instance: Any) -> None:
     """Setup default permissions on newly created entities according to.
 
     :attr:`Entity.__default_permissions__`.
@@ -104,11 +106,12 @@ def setup_default_permissions(session, instance):
     _setup_default_permissions(instance)
 
 
-def _setup_default_permissions(instance):
+def _setup_default_permissions(instance: Any) -> None:
     """Separate method to conveniently call it from scripts for example."""
     from abilian.services import get_service
+    from abilian.services.security import SecurityService
 
-    security = get_service("security")
+    security = cast(SecurityService, get_service("security"))
     for permission, roles in instance.__default_permissions__:
         if permission == "create":
             # use str for comparison instead of `abilian.services.security.CREATE`
@@ -120,7 +123,7 @@ def _setup_default_permissions(instance):
             security.add_permission(permission, role, obj=instance)
 
 
-class _EntityInherit(object):
+class _EntityInherit:
     """Mixin for Entity subclasses.
 
     Entity meta-class takes care of inserting it in base classes.
@@ -129,7 +132,7 @@ class _EntityInherit(object):
     __indexable__ = True
 
     @declared_attr
-    def id(cls):
+    def id(cls) -> Column:
         return Column(
             Integer,
             ForeignKey("entity.id", use_alter=True, name="fk_inherited_entity_id"),
@@ -149,7 +152,9 @@ BaseMeta = db.Model.__class__
 
 
 class EntityQuery(db.Model.query_class):
-    def with_permission(self, permission, user=None):
+    def with_permission(
+        self, permission: "Permission", user: Optional["User"] = None
+    ) -> "EntityQuery":
         from abilian.services import get_service
 
         security = get_service("security")
@@ -170,7 +175,12 @@ class EntityMeta(BaseMeta):
     `_EntityInherit` provides `id` attibute and `__mapper_args__`
     """
 
-    def __new__(mcs, classname, bases, d):
+    def __new__(
+        mcs: Type["EntityMeta"],
+        classname: str,
+        bases: Tuple[Type, ...],
+        d: Dict[str, Any],
+    ) -> Any:
         if d["__module__"] != EntityMeta.__module__ or classname != "Entity":
             if not any(issubclass(b, _EntityInherit) for b in bases):
                 bases = (_EntityInherit,) + bases
@@ -206,28 +216,27 @@ class EntityMeta(BaseMeta):
                 )
                 d["__default_permissions__"] = default_permissions
 
-            d["SLUG_SEPARATOR"] = text_type(
-                d.get("SLUG_SEPARATOR", Entity.SLUG_SEPARATOR)
-            )
+            d["SLUG_SEPARATOR"] = str(d.get("SLUG_SEPARATOR", Entity.SLUG_SEPARATOR))
 
         cls = BaseMeta.__new__(mcs, classname, bases, d)
 
         if not issubclass(cls.query_class, EntityQuery):
             raise TypeError(
-                "query_class is not a subclass of EntityQuery: {!r}"
-                "".format(cls.query_class)
+                f"query_class is not a subclass of EntityQuery: {cls.query_class!r}"
             )
 
         event.listen(cls, "before_insert", auto_slug_on_insert)
         event.listen(cls, "after_insert", auto_slug_after_insert)
         return cls
 
-    def __init__(cls, classname, bases, d):
+    def __init__(
+        cls, classname: str, bases: Tuple[Type, ...], d: Dict[str, Any]
+    ) -> None:
         bases = cls.__bases__
         BaseMeta.__init__(cls, classname, bases, d)
 
 
-class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
+class Entity(Indexable, BaseMixin, Model, metaclass=EntityMeta):
     """Base class for Abilian entities.
 
     From Sqlalchemy POV, Entities use `Joined-Table inheritance
@@ -252,19 +261,12 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
               return args
     """
 
-    # __metaclass__ = EntityMeta
     __indexable__ = False
-    __indexation_args__ = {}
-    __indexation_args__.update(Indexable.__indexation_args__)
-    index_to = __indexation_args__.setdefault("index_to", ())
-    index_to += BaseMixin.__indexation_args__.setdefault("index_to", ())
-    index_to += (
+    __index_to__ = (
         ("_indexable_roles_and_users", ("allowed_roles_and_users",)),
         ("_indexable_tag_ids", ("tag_ids",)),
         ("_indexable_tag_text", ("tag_text", "text")),
     )
-    __indexation_args__["index_to"] = index_to
-    del index_to
 
     __default_permissions__ = frozenset()
     """
@@ -300,7 +302,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
     query_class = EntityQuery
 
     @declared_attr
-    def __mapper_args__(cls):
+    def __mapper_args__(cls) -> Dict[str, Any]:
         if cls.__module__ == __name__ and cls.__name__ == "Entity":
             return {"polymorphic_on": "_entity_type"}
 
@@ -328,7 +330,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
     """
 
     _entity_type = Column("entity_type", String(1000), nullable=False)
-    entity_type = None
+    entity_type = ""
 
     meta = Column(JSONDict(), nullable=False, default=dict, server_default="{}")
     """
@@ -339,23 +341,23 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
     """
 
     @property
-    def object_type(self):
-        return text_type(self.entity_type)
+    def object_type(self) -> str:
+        return str(self.entity_type)
 
     @classmethod
-    def _object_type(cls):
+    def _object_type(cls) -> str:
         # overriden from Indexable
         return cls.entity_type
 
     @property
-    def entity_class(self):
+    def entity_class(self) -> str:
         return self.entity_type and friendly_fqcn(self.entity_type)
 
     # Default magic metadata, should not be necessary
     # TODO: remove
-    __editable__ = frozenset()
-    __searchable__ = frozenset()
-    __auditable__ = frozenset()
+    __editable__: FrozenSet = frozenset()
+    __searchable__: FrozenSet = frozenset()
+    __auditable__: FrozenSet = frozenset()
 
     def __init__(self, *args, **kwargs):
         db.Model.__init__(self, *args, **kwargs)
@@ -365,7 +367,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
             self.meta = {}
 
     @property
-    def auto_slug(self):
+    def auto_slug(self) -> str:
         """This property is used to auto-generate a slug from the name
         attribute.
 
@@ -376,7 +378,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
             slug = slugify(slug, separator=self.SLUG_SEPARATOR)
             session = sa.orm.object_session(self)
             if not session:
-                return None
+                return ""
             query = session.query(Entity.slug).filter(
                 Entity._entity_type == self.object_type
             )
@@ -391,19 +393,20 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
             max_id = max(-1, -1, *results) + 1
             if max_id:
-                slug = "{}-{}".format(slug, max_id)
+                slug = f"{slug}-{max_id}"
         return slug
 
     @property
-    def _indexable_roles_and_users(self):
+    def _indexable_roles_and_users(self) -> str:
         """Return a string made for indexing roles having :any:`READ`
         permission on this object."""
-        from abilian.services.indexing import indexable_role
-        from abilian.services.security import READ, Admin, Anonymous, Creator, Owner
         from abilian.services import get_service
+        from abilian.services.indexing import indexable_role
+        from abilian.services.security import READ, Admin, Anonymous, \
+            Creator, Owner, SecurityService
 
         result = []
-        security = get_service("security")
+        security = cast(SecurityService, get_service("security"))
 
         # roles - required to match when user has a global role
         assignments = security.get_permissions_assignments(permission=READ, obj=self)
@@ -436,24 +439,23 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
         return " ".join(result)
 
     @property
-    def _indexable_tags(self):
+    def _indexable_tags(self) -> List["Tag"]:
         """Index tag ids for tags defined in this Entity's default tags
         namespace."""
-        tags = current_app.extensions["tags"]
-
-        if not tags.supports_taggings(self):
-            return ""
+        tags = current_app.extensions.get("tags")
+        if not tags or not tags.supports_taggings(self):
+            return []
 
         default_ns = tags.entity_default_ns(self)
         return [t for t in tags.entity_tags(self) if t.ns == default_ns]
 
     @property
-    def _indexable_tag_ids(self):
-        return " ".join(text_type(t.id) for t in self._indexable_tags)
+    def _indexable_tag_ids(self) -> str:
+        return " ".join(str(t.id) for t in self._indexable_tags)
 
     @property
-    def _indexable_tag_text(self):
-        return " ".join(text_type(t.label) for t in self._indexable_tags)
+    def _indexable_tag_text(self) -> str:
+        return " ".join(str(t.label) for t in self._indexable_tags)
 
     def clone(self):
         """Copy an entity: copy every field, except the id and sqlalchemy
@@ -479,7 +481,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
 # TODO: make this unecessary
 @event.listens_for(Entity, "class_instrument", propagate=True)
-def register_metadata(cls):
+def register_metadata(cls: Type[Entity]) -> None:
     cls.__editable__ = set()
 
     # TODO: use SQLAlchemy 0.8 introspection
@@ -497,7 +499,9 @@ def register_metadata(cls):
 
 
 @event.listens_for(Session, "before_flush")
-def polymorphic_update_timestamp(session, flush_context, instances):
+def polymorphic_update_timestamp(
+    session: Session, flush_context: UOWTransaction, instances: Any
+) -> None:
     """This listener ensures an update statement is emited for "entity" table
     to update 'updated_at'.
 
@@ -523,8 +527,3 @@ def all_entity_classes():
     return [
         cls for cls in persistent_classes if isclass(cls) and issubclass(cls, Entity)
     ]
-
-
-def register_all_entity_classes():
-    for cls in all_entity_classes():
-        register_metadata(cls)
