@@ -1,33 +1,43 @@
-# coding=utf-8
 """Create all standard extensions."""
 
 # Note: Because of issues with circular dependencies, Abilian-specific
 # extensions are created later.
-
-from __future__ import absolute_import, division, print_function
+import sqlite3
+from typing import Any
 
 import flask_mail
 import sqlalchemy as sa
 import sqlalchemy.event
 import sqlalchemy.orm
 from flask import current_app
-from sqlalchemy.engine import Engine
+from sqlalchemy.engine import Connection, Engine
+from sqlalchemy.sql.schema import MetaData
 
 from abilian.core.logging import patch_logger
+from abilian.core.sqlalchemy import SQLAlchemy
 
 from . import upstream_info
-from ..sqlalchemy import SQLAlchemy
 from .csrf import abilian_csrf
 from .csrf import wtf_csrf as csrf
+from .jinjaext import DeferredJS
 from .login import login_manager
+from .redis import Redis
 
-__all__ = ["get_extension", "db", "mail", "login_manager", "csrf", "upstream_info"]
+__all__ = (
+    "get_extension",
+    "redis",
+    "db",
+    "mail",
+    "login_manager",
+    "csrf",
+    "upstream_info",
+)
 
 
 # patch flask.ext.mail.Message.send to always set enveloppe_from default mail
 # sender
 # FIXME: we'ld rather subclass Message and update all imports
-def _message_send(self, connection):
+def _message_send(self: Any, connection: flask_mail.Connection) -> None:
     """Send a single message instance.
 
     If TESTING is True the message will not actually be sent.
@@ -48,10 +58,16 @@ mail = flask_mail.Mail()
 
 db = SQLAlchemy()
 
+redis = Redis()
+
+deferred_js = DeferredJS()
+
 
 @sa.event.listens_for(db.metadata, "before_create")
 @sa.event.listens_for(db.metadata, "before_drop")
-def _filter_metadata_for_connection(target, connection, **kw):
+def _filter_metadata_for_connection(
+    target: MetaData, connection: Connection, **kw: Any
+) -> None:
     """Listener to control what indexes get created.
 
     Useful for skipping postgres-specific indexes on a sqlite for example.
@@ -72,13 +88,13 @@ def _filter_metadata_for_connection(target, connection, **kw):
 #
 # CSRF
 #
-def get_extension(name):
+def get_extension(name: str):
     """Get the named extension from the current app, returning None if not
     found."""
     return current_app.extensions.get(name)
 
 
-def _install_get_display_value(cls):
+def _install_get_display_value(cls: Any) -> None:
 
     _MARK = object()
 
@@ -125,10 +141,8 @@ sa.event.listen(db.Model, "class_instrument", _install_get_display_value)
 # Make Sqlite a bit more well-behaved.
 #
 @sa.event.listens_for(Engine, "connect")
-def _set_sqlite_pragma(dbapi_connection, connection_record):
-    from sqlite3 import Connection as SQLite3Connection
-
-    if isinstance(dbapi_connection, SQLite3Connection):  # pragma: no cover
+def _set_sqlite_pragma(dbapi_connection: Any, connection_record: Any) -> None:
+    if isinstance(dbapi_connection, sqlite3.Connection):  # pragma: no cover
         cursor = dbapi_connection.cursor()
         cursor.execute("PRAGMA foreign_keys=ON;")
         cursor.close()
