@@ -1,10 +1,11 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from typing import TYPE_CHECKING, Set
 
 from flask_login import AnonymousUserMixin, LoginManager
 
+if TYPE_CHECKING:
+    from abilian.core.models.subjects import Group
+
 
 class AnonymousUser(AnonymousUserMixin):
     def has_role(self, role):
@@ -14,7 +15,7 @@ class AnonymousUser(AnonymousUserMixin):
         return security.has_role(self, role)
 
     @property
-    def groups(self):
+    def groups(self) -> Set["Group"]:
         return set()
 
 
