@@ -1,39 +1,22 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function
-
 import json
 from datetime import datetime
 
-from six import python_2_unicode_compatible
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm.util import class_mapper
 
-from .base import (
-    AUDITABLE,
-    AUDITABLE_HIDDEN,
-    EDITABLE,
-    EXPORTABLE,
-    NOT_AUDITABLE,
-    NOT_EDITABLE,
-    NOT_EXPORTABLE,
-    NOT_SEARCHABLE,
-    SEARCHABLE,
-    SYSTEM,
-    IdMixin,
-    Model,
-    TimestampedMixin,
-)
+from .base import AUDITABLE, AUDITABLE_HIDDEN, EDITABLE, EXPORTABLE, \
+    NOT_AUDITABLE, NOT_EDITABLE, NOT_EXPORTABLE, NOT_SEARCHABLE, SEARCHABLE, \
+    SYSTEM, IdMixin, Model, TimestampedMixin
 from .owned import OwnedMixin
 
 
-@python_2_unicode_compatible
 class BaseMixin(IdMixin, TimestampedMixin, OwnedMixin):
     @declared_attr
     def __tablename__(cls):
         return cls.__name__.lower()
 
-    def __init__(self):
+    def __init__(self) -> None:
         OwnedMixin.__init__(self)
 
     def __repr__(self):
@@ -63,7 +46,7 @@ class BaseMixin(IdMixin, TimestampedMixin, OwnedMixin):
 
     def _icon(self, size=12):
         class_name = self.__class__.__name__.lower()
-        return "/static/icons/{}-{}.png".format(class_name, size)
+        return f"/static/icons/{class_name}-{size}.png"
 
     # FIXME: we can do better than that
     @property
