@@ -1,15 +1,11 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import abc
 from functools import total_ordering
 
 import sqlalchemy as sa
 import sqlalchemy.orm
-from six import add_metaclass, python_2_unicode_compatible, text_type
 
 from abilian.core.entities import Entity
+from abilian.core.extensions import db
 
 from .base import IdMixin, Model
 
@@ -17,8 +13,7 @@ from .base import IdMixin, Model
 TAGS_ATTR = "__tags__"
 
 
-@add_metaclass(abc.ABCMeta)
-class SupportTagging(object):
+class SupportTagging(metaclass=abc.ABCMeta):
     pass
 
 
@@ -56,7 +51,7 @@ def supports_tagging(obj):
     return True
 
 
-entity_tag_tbl = sa.Table(
+entity_tag_tbl = db.Table(
     "entity_tags",
     Model.metadata,
     sa.Column("tag_id", sa.Integer, sa.ForeignKey("tag.id", ondelete="CASCADE")),
@@ -66,7 +61,6 @@ entity_tag_tbl = sa.Table(
 
 
 @total_ordering
-@python_2_unicode_compatible
 class Tag(IdMixin, Model):
     """Tags are text labels that can be attached to :class:`entities.Entity`.
 
@@ -106,7 +100,7 @@ class Tag(IdMixin, Model):
         return self.label
 
     def __lt__(self, other):
-        return text_type(self).lower().__lt__(text_type(other).lower())
+        return str(self).lower().__lt__(str(other).lower())
 
     def __repr__(self):
         cls = self.__class__
