@@ -1,4 +1,3 @@
-# coding=utf-8
 """All signals used by Abilian Core.
 
 Signals are the main tools used for decoupling applications components by
@@ -10,9 +9,6 @@ Cf. http://flask.pocoo.org/docs/signals/ for detailed documentation.
 The main signal is currently :obj:`activity`.
 """
 
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from blinker.base import Namespace
 
 signals = Namespace()
