@@ -1,20 +1,22 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from typing import Any, Dict, Optional, Tuple, Type
 
-from six import python_2_unicode_compatible, text_type, with_metaclass
+from sqlalchemy.engine.interfaces import Dialect
 from sqlalchemy.types import String, TypeDecorator
 
 
 class ValueSingletonMeta(type):
-    def __new__(cls, name, bases, dct):
+    def __new__(
+        mcs: Type["ValueSingletonMeta"],
+        name: str,
+        bases: Tuple[Type],
+        dct: Dict[str, Any],
+    ) -> Type:
         dct["__instances__"] = {}
         dct.setdefault("__slots__", ())
-        new_type = type.__new__(cls, name, bases, dct)
+        new_type = type.__new__(mcs, name, bases, dct)
         return new_type
 
-    def __call__(cls, value, *args, **kwargs):
+    def __call__(cls, value: Any, *args, **kwargs) -> Any:
         if isinstance(value, cls):
             return value
 
@@ -24,37 +26,35 @@ class ValueSingletonMeta(type):
         return cls.__instances__[value.lower()]
 
 
-@python_2_unicode_compatible
-class UniqueName(with_metaclass(ValueSingletonMeta, object)):
+class UniqueName(metaclass=ValueSingletonMeta):
     """Base class to create singletons from strings.
 
     A subclass of :class:`UniqueName` defines a namespace.
     """
 
-    # __metaclass__ = ValueSingletonMeta
     __slots__ = ("_hash", "__name")
     attr = "name"
 
-    def __init__(self, name):
-        self.__name = text_type(name).strip().lower()
+    def __init__(self, name: str) -> None:
+        self.__name = str(name).strip().lower()
         self._hash = hash(self.__name)
 
     @property
-    def name(self):
+    def name(self) -> str:
         return self.__name
 
     def __repr__(self):
-        return "{}({})".format(self.__class__.__name__, repr(self.name))
+        return f"{self.__class__.__name__}({repr(self.name)})"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.name
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         if isinstance(other, self.__class__):
             return self._hash == other._hash
-        return self.__name == text_type(other)
+        return self.__name == str(other)
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return self._hash
 
 
@@ -70,20 +70,20 @@ class UniqueNameType(TypeDecorator):
     """
 
     impl = String
-    Type = None
+    Type: type
     default_max_length = 100
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         assert self.Type is not None
         kwargs.setdefault("length", self.default_max_length)
         TypeDecorator.__init__(self, *args, **kwargs)
 
-    def process_bind_param(self, value, dialect):
+    def process_bind_param(self, value: Any, dialect: Dialect) -> Optional[str]:
         if value is not None:
             value = str(value)
         return value
 
-    def process_result_value(self, value, dialect):
+    def process_result_value(self, value: Optional[str], dialect: Dialect) -> Any:
         if value is not None:
             value = self.Type(value)
         return value
