@@ -1,7 +1,3 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from sqlalchemy import Column, Text, UnicodeText
 
 from abilian.core.entities import SEARCHABLE, Entity
