@@ -1,35 +1,40 @@
-# coding=utf-8
-""""""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from typing import TYPE_CHECKING, Any, List, Optional
 
 import sqlalchemy as sa
 from sqlalchemy.orm import object_session
 
 from abilian.core.entities import Entity
+from abilian.core.models.subjects import User
 from abilian.core.signals import activity
 from abilian.services import Service
 
 from .models import ActivityEntry
 
+if TYPE_CHECKING:
+    pass
+
 __all__ = ["ActivityService"]
 
 
 class ActivityService(Service):
     name = "activity"
 
-    def init_app(self, app):
-        Service.init_app(self, app)
-
-    def start(self, **kw):
-        Service.start(self)
+    def start(self, ignore_state: bool = False) -> None:
+        super().start(ignore_state)
         activity.connect(self.log_activity)
 
-    def stop(self, **kw):
-        Service.stop(self)
+    def stop(self, ignore_state: bool = False) -> None:
+        super().stop(ignore_state)
         activity.disconnect(self.log_activity)
 
-    def log_activity(self, sender, actor, verb, object, target=None):
+    def log_activity(
+        self,
+        sender: None,
+        actor: User,
+        verb: str,
+        object: Any,
+        target: Optional[Entity] = None,
+    ) -> None:
         assert self.running
         if not isinstance(object, Entity):
             # generic forms may send signals inconditionnaly. For now we have activity
@@ -58,7 +63,7 @@ class ActivityService(Service):
         session.add(entry)
 
     @staticmethod
-    def entries_for_actor(actor, limit=50):
+    def entries_for_actor(actor: User, limit: int = 50) -> List[ActivityEntry]:
         return (
             ActivityEntry.query.filter(ActivityEntry.actor == actor).limit(limit).all()
         )
