@@ -1,4 +1,3 @@
-# coding=utf-8
 """Audit Service: logs modifications to audited objects.
 
 Only subclasses of Entity are auditable, at this point.
@@ -8,15 +7,13 @@ TODO: In the future, we may decide to:
 - Make Models that have the __auditable__ property (set to True) auditable.
 - Make Entities that have the __auditable__ property set to False not auditable.
 """
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import logging
 import pickle
 from datetime import datetime
+from typing import Any
 
 from flask import current_app
-from six import binary_type, text_type
+from flask_sqlalchemy import BaseQuery
 from sqlalchemy import LargeBinary
 from sqlalchemy.orm import relationship
 from sqlalchemy.orm.base import NEVER_SET
@@ -35,10 +32,10 @@ RELATED = 1 << 7
 logger = logging.getLogger(__name__)
 
 
-class Changes(object):
+class Changes:
     """Trace object modifications."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.columns = {}
         self.collections = {}
 
@@ -55,14 +52,14 @@ class Changes(object):
 
         return c
 
-    def set_column_changes(self, name, old_value, new_value):
+    def set_column_changes(self, name: str, old_value: Any, new_value: Any) -> None:
         self.columns[name] = (old_value, new_value)
 
-    def set_related_changes(self, name, changes):
+    def set_related_changes(self, name: str, changes: "Changes") -> None:
         assert isinstance(changes, Changes)
         self.columns[name] = changes
 
-    def _collection_change(self, name, value, add):
+    def _collection_change(self, name: str, value: Any, add: bool) -> None:
         colls = self.collections
         to_add, to_remove = colls.setdefault(name, (set(), set()))
         if not add:
@@ -74,18 +71,15 @@ class Changes(object):
         if value in to_remove:
             to_remove.remove(value)
 
-    def collection_append(self, name, value):
+    def collection_append(self, name: str, value: Any) -> None:
         self._collection_change(name, value, add=True)
 
-    def collection_remove(self, name, value):
+    def collection_remove(self, name: str, value: Any):
         self._collection_change(name, value, add=False)
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self.columns) or bool(self.collections)
 
-    # Py2 compat
-    __nonzero__ = __bool__
-
 
 class AuditEntry(db.Model):
     """Logs modifications to auditable classes."""
@@ -109,28 +103,32 @@ class AuditEntry(db.Model):
 
     changes_pickle = Column(LargeBinary)
 
+    query: BaseQuery
+
     def __repr__(self):
         return "<AuditEntry id={} op={} user={} {}entity=<{} id={}>>".format(
             repr(self.id),
             {CREATION: "CREATION", DELETION: "DELETION", UPDATE: "UPDATE"}[self.op],
-            repr(text_type(self.user)),
+            repr(str(self.user)),
             "related " if self.related else "",
             self.entity_type,
             self.entity_id,
         )
 
     @property
-    def op(self):
+    def op(self) -> int:
         return self.type & ~RELATED
 
     @property
-    def related(self):
+    def related(self) -> int:
         return self.type & RELATED
 
-    def get_changes(self):
+    def get_changes(self) -> Changes:
         # Using Pickle here instead of JSON because we need to pickle values
         # such as dates. This could make schema migration more difficult,
         # though.
+        #
+        # Convoluted and buggy code below to manage the PY2 -> PY3 transition
         if self.changes_pickle:
             # XXX: this workaround may or may not work
             try:
@@ -138,19 +136,27 @@ class AuditEntry(db.Model):
             except (UnicodeDecodeError, TypeError):
                 try:
                     changes = pickle.loads(self.changes_pickle, encoding="bytes")
-                except BaseException:
+                except Exception:
                     logger.warning("migration error on audit entry:", exc_info=True)
                     changes = Changes()
 
             if isinstance(changes, dict):
                 changes = Changes.from_legacy(changes)
 
-            # Fix for migration Python 2 -> Python 3
-            items = list(vars(changes).items())
-            for k, v in items:
-                if isinstance(k, bytes):
-                    setattr(changes, k.decode(), v)
-                    del changes.__dict__[k]
+            def fix_migration(changes):
+                # Fix for migration Python 2 -> Python 3
+                items = list(vars(changes).items())
+                for k, v in items:
+                    if isinstance(k, bytes):
+                        setattr(changes, k.decode(), v)
+                        del changes.__dict__[k]
+
+                for k in changes.columns:
+                    v = changes.columns[k]
+                    if isinstance(v, Changes):
+                        fix_migration(v)
+
+            fix_migration(changes)
 
         else:
             changes = Changes()
@@ -169,26 +175,26 @@ class AuditEntry(db.Model):
 
         return changes
 
-    def set_changes(self, changes):
+    def set_changes(self, changes: Changes) -> None:
         changes = self._format_changes(changes)
         self.changes_pickle = pickle.dumps(changes, protocol=2)
 
     changes = property(get_changes, set_changes)
 
-    def _format_changes(self, changes):
+    def _format_changes(self, changes: Changes) -> Changes:
         uchanges = Changes()
         if isinstance(changes, dict):
             changes = Changes.from_legacy(changes)
 
         for k, v in changes.columns.items():
-            k = text_type(k)
+            k = str(k)
             uv = []
             if isinstance(v, Changes):
                 # field k is a related model with its own changes
                 uv = self._format_changes(v)
             else:
                 for val in v:
-                    if isinstance(val, binary_type):
+                    if isinstance(val, bytes):
                         # TODO: Temp fix for errors that happen during
                         # migration
                         try:
@@ -203,8 +209,8 @@ class AuditEntry(db.Model):
             uchanges.columns[k] = uv
 
         for attr_name, (appended, removed) in changes.collections.items():
-            appended = sorted(text_type(i) for i in appended)
-            removed = sorted(text_type(i) for i in removed)
+            appended = sorted(str(i) for i in appended)
+            removed = sorted(str(i) for i in removed)
             uchanges.collections[attr_name] = (appended, removed)
 
         return uchanges
