@@ -1,8 +1,4 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from datetime import datetime
 
 from flask import request
@@ -18,23 +14,22 @@ _MARK = object()
 
 
 class LoginSessionQuery(BaseQuery):
-    def get_active_for(self, user, user_agent=_MARK, ip_address=_MARK):
+    def get_active_for(
+        self, user: User, user_agent: object = _MARK, ip_address: object = _MARK
+    ) -> "LoginSession":
         """Return last known session for given user.
 
         :param user: user session
-        :type user: `abilian.core.models.subjects.User`
 
         :param user_agent: *exact* user agent string to lookup, or `None` to have
         user_agent extracted from request object. If not provided at all, no
         filtering on user_agent.
-        :type user_agent: string or None, or absent
 
         :param ip_address: client IP, or `None` to have ip_address extracted from
         request object (requires header 'X-Forwarded-For'). If not provided at
         all, no filtering on ip_address.
-        :type ip_address: string or None, or absent
 
-        :rtype: `LoginSession` or `None` if no session is found.
+        :returns: `LoginSession` or `None` if no session is found.
         """
         conditions = [LoginSession.user == user]
 
@@ -61,6 +56,7 @@ class LoginSession(db.Model):
 
     __tablename__ = "login_session"
     query_class = LoginSessionQuery
+    query: LoginSessionQuery
 
     id = Column(Integer, primary_key=True, autoincrement=True)
 
@@ -80,7 +76,7 @@ class LoginSession(db.Model):
     user_agent = Column(String(512), default="", nullable=False)
 
     @staticmethod
-    def new():
+    def new() -> "LoginSession":
         user_agent = request.environ.get("HTTP_USER_AGENT", "")
         forwared_for = request.headers.getlist("X-Forwarded-For")
         if not forwared_for:
