@@ -1,4 +1,3 @@
-# coding=utf-8
 """Conversion service.
 
 Hardcoded to manage only conversion to PDF, to text and to image series.
@@ -9,17 +8,11 @@ Assumes poppler-utils and LibreOffice are installed.
 
 TODO: rename Converter into ConversionService ?
 """
+from abilian.services.conversion.handlers import ImageMagickHandler, \
+    LibreOfficePdfHandler, PdfToPpmHandler, PdfToTextHandler
 
-from __future__ import absolute_import
-
-from abilian.services.conversion.handlers import (
-    ImageMagickHandler,
-    LibreOfficePdfHandler,
-    PdfToPpmHandler,
-    PdfToTextHandler,
-)
-
-from .service import ConversionError, Converter, HandlerNotFound
+from .exceptions import ConversionError
+from .service import Converter, HandlerNotFound
 
 # Singleton, yuck!
 converter = Converter()
