@@ -1,14 +1,10 @@
-# coding=utf-8
 """Provides tools (currently: only functions, not a real service) for image
 processing."""
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import hashlib
 from io import BytesIO
-from typing import Dict
+from typing import Any, Dict, Tuple, Union
 
 from PIL import Image
-from six import binary_type
 
 __all__ = ["resize", "get_format", "RESIZE_MODES", "SCALE", "FIT", "CROP"]
 
@@ -28,11 +24,11 @@ CROP = "crop"
 RESIZE_MODES = frozenset({SCALE, FIT, CROP})
 
 # TODO: cache to file
-cache = {}  # type: Dict[str, bytes]
+cache: Dict[Any, bytes] = {}
 
 
-def open_image(img):
-    if isinstance(img, binary_type):
+def open_image(img: Union[BytesIO, bytes]) -> Image.Image:
+    if isinstance(img, bytes):
         img = BytesIO(img)
 
     pos = img.tell()
@@ -43,24 +39,24 @@ def open_image(img):
 
 def get_format(img):
     if not img:
-        raise IOError()
+        raise OSError()
     image = open_image(img)
     return image.format
 
 
-def get_size(img):
+def get_size(img: bytes) -> Tuple[int, int]:
     image = open_image(img)
     return image.size
 
 
-def get_save_format(fmt):
+def get_save_format(fmt: str) -> str:
     if fmt in ("GIF", "PNG"):
         return "PNG"
     return "JPEG"
 
 
-def resize(orig, width, height, mode=FIT):
-    if isinstance(orig, binary_type):
+def resize(orig: Any, width: int, height: int, mode: str = FIT) -> bytes:
+    if isinstance(orig, bytes):
         orig = BytesIO(orig)
 
     digest = hashlib.md5(orig.read()).digest()
@@ -97,7 +93,7 @@ def resize(orig, width, height, mode=FIT):
     return converted
 
 
-def _crop_and_resize(image, width, height=0):
+def _crop_and_resize(image: Image.Image, width: int, height: int = 0) -> Image.Image:
     if not height:
         height = width
 
