@@ -1,7 +1,3 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from pathlib import Path
 
 from pytest import fixture
@@ -10,12 +6,12 @@ from .. import CROP, SCALE, get_save_format, get_size, resize
 
 
 @fixture
-def orig_image():
+def orig_image() -> bytes:
     # 725x518
     return (Path(__file__).parent / "cat.jpg").open("rb").read()
 
 
-def test_get_save_format():
+def test_get_save_format() -> None:
     assert get_save_format("JPG") == "JPEG"
     assert get_save_format("JPEG") == "JPEG"
     assert get_save_format("PNG") == "PNG"
@@ -23,7 +19,7 @@ def test_get_save_format():
     assert get_save_format("unknown") == "JPEG"
 
 
-def test_fit(orig_image):
+def test_fit(orig_image: bytes) -> None:
     image = resize(orig_image, 500, 500)
     x, y = get_size(image)
     assert (x, y) == (500, 357)
@@ -34,11 +30,11 @@ def test_fit(orig_image):
     assert x == 725 and y == 518
 
 
-def test_scale(orig_image):
+def test_scale(orig_image: bytes) -> None:
     image = resize(orig_image, 500, 500, SCALE)
     assert get_size(image) == (500, 500)
 
 
-def test_crop(orig_image):
+def test_crop(orig_image: bytes) -> None:
     image = resize(orig_image, 500, 500, CROP)
     assert get_size(image) == (500, 500)
