@@ -1,12 +1,9 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from whoosh.analysis import CharsetFilter, LowercaseFilter, NgramFilter, \
     PathTokenizer, RegexTokenizer
+#: A Whoosh analyzer that splits on word boundaries and folds accents and case.
 from whoosh.fields import DATETIME, ID, KEYWORD, NUMERIC, TEXT, FieldType, \
-    SchemaClass
+    Schema, SchemaClass
 from whoosh.formats import Existence
 from whoosh.support.charset import accent_map
 
@@ -14,7 +11,6 @@ from abilian.core.models.subjects import Group, User
 from abilian.core.util import unwrap
 from abilian.services.security.models import Anonymous, Role
 
-#: A Whoosh analyzer that splits on word boundaries and folds accents and case.
 accent_folder = (
     RegexTokenizer(r"\w+")
     | LowercaseFilter()  # defaults doesn't split on '.'
@@ -25,7 +21,7 @@ accent_folder = (
 edge_ngram = accent_folder | NgramFilter(minsize=2, maxsize=6, at="start")
 
 
-def EdgeNgramField():
+def EdgeNgramField() -> TEXT:
     return TEXT(analyzer=edge_ngram)
 
 
@@ -61,14 +57,14 @@ _default_dyn_fields = {
 }
 
 
-def DefaultSearchSchema(*args, **kwargs):
+def DefaultSearchSchema(*args, **kwargs) -> Schema:
     schema = _DefaultSearchSchema()
     for name, field in _default_dyn_fields.items():
         schema.add(name, field, glob=True)
     return schema
 
 
-def indexable_role(principal):
+def indexable_role(principal: Role) -> str:
     """Return a string suitable for query against `allowed_roles_and_users`
     field.
 
@@ -82,7 +78,7 @@ def indexable_role(principal):
         principal = Anonymous
 
     if isinstance(principal, Role):
-        return "role:{}".format(principal.name)
+        return f"role:{principal.name}"
     elif isinstance(principal, User):
         fmt = "user:{:d}"
     elif isinstance(principal, Group):
