@@ -1,38 +1,29 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from datetime import datetime
+from typing import Any, Dict
 
-import six
 import sqlalchemy as sa
 from whoosh.fields import NUMERIC, TEXT, Schema
 
 from abilian.core.entities import Entity
-from abilian.core.extensions import db
 from abilian.core.models.base import SEARCHABLE, IdMixin
 from abilian.core.models.base import Indexable as CoreIndexable
+from abilian.core.models.base import Model
 from abilian.services.indexing.adapter import SAAdapter
 
 
-class SANotAdaptable(object):
+class SANotAdaptable:
     pass
 
 
-class SANotIndexable(IdMixin, db.Model):
+class SANotIndexable(IdMixin, Model):
     __tablename__ = "sa_not_indexable"
     __indexable__ = False
 
 
-class Indexable(IdMixin, CoreIndexable, db.Model):
+class Indexable(IdMixin, CoreIndexable, Model):
     __tablename__ = "sa_indexable"
-    __indexation_args__ = {
-        "index_to": (
-            ("related.name", ("name", "text")),
-            ("related.description", "text"),
-        )
-    }
+    __index_to__ = (("related.name", ("name", "text")), ("related.description", "text"))
 
     num = sa.Column(sa.Integer, info=SEARCHABLE | {"index_to": (("num", NUMERIC()),)})
 
@@ -41,70 +32,92 @@ class SubclassEntityIndexable(Entity):
     pass
 
 
-def test_can_adapt():
+def test_can_adapt() -> None:
     assert not SAAdapter.can_adapt(SANotAdaptable)
     assert SAAdapter.can_adapt(SANotIndexable)
     assert SAAdapter.can_adapt(Indexable)
     assert SAAdapter.can_adapt(Entity)
 
 
-def test_build_attrs():
+def test_build_attrs_1() -> None:
     schema = Schema()
     adapter = SAAdapter(SANotIndexable, schema)
     assert not adapter.indexable
     assert adapter.doc_attrs == {}
 
+
+def test_build_attrs_2() -> None:
+    schema = Schema()
     adapter = SAAdapter(Entity, schema)
     assert adapter.indexable == False
 
+
+def test_build_attrs_3() -> None:
+    schema = Schema()
     adapter = SAAdapter(SubclassEntityIndexable, schema)
     assert adapter.indexable
     assert set(adapter.doc_attrs) == {
-        "object_key",
+        "allowed_roles_and_users",
+        "created_at",
+        "creator",
+        "creator_name",
         "id",
         "name",
-        "slug",
-        "object_type",
-        "text",
-        "created_at",
-        "updated_at",
         "name_prefix",
+        "object_key",
+        "object_type",
         "owner",
         "owner_name",
-        "creator_name",
-        "creator",
-        "allowed_roles_and_users",
+        "slug",
         "tag_ids",
         "tag_text",
+        "text",
+        "updated_at",
     }
-    assert all(lambda f: callable(f) for f in six.itervalues(adapter.doc_attrs))
+    assert all(lambda f: callable(f) for f in adapter.doc_attrs.values())
 
     assert set(schema.names()) == {
-        "object_key",
-        "id",
-        "object_type",
-        "name",
-        "slug",
-        "text",
+        "allowed_roles_and_users",
         "created_at",
-        "updated_at",
+        "creator",
+        "creator_name",
+        "id",
+        "name",
         "name_prefix",
+        "object_key",
+        "object_type",
         "owner",
         "owner_name",
-        "creator_name",
-        "creator",
-        "allowed_roles_and_users",
+        "slug",
         "tag_ids",
         "tag_text",
+        "text",
+        "updated_at",
     }
 
+
+def test_build_attrs_4() -> None:
     schema = Schema(id=NUMERIC(bits=64, signed=False, stored=True, unique=True))
     adapter = SAAdapter(Indexable, schema)
     assert adapter.indexable
-    assert set(adapter.doc_attrs) == {"id", "text", "num", "name"}
-    assert all(lambda f: callable(f) for f in six.itervalues(adapter.doc_attrs))
+    assert set(adapter.doc_attrs) == {
+        "id",
+        "text",
+        "num",
+        "name",
+        "object_type",
+        "object_key",
+    }
+    assert all(lambda f: callable(f) for f in adapter.doc_attrs.values())
 
-    assert set(schema.names()) == {"id", "text", "num", "name"}
+    assert set(schema.names()) == {
+        "id",
+        "text",
+        "num",
+        "name",
+        "object_type",
+        "object_key",
+    }
     assert isinstance(schema["text"], TEXT)
     assert isinstance(schema["num"], NUMERIC)
 
@@ -132,19 +145,19 @@ def test_get_document(app, db):
         assert adapter.get_document(obj) == expected
 
 
-def test_get_document_with_schema():
+def test_get_document_with_schema() -> None:
     # test retrieve related attributes
     schema = Schema(id=NUMERIC(bits=64, signed=False, stored=True, unique=True))
     adapter = SAAdapter(Indexable, schema)
-    expected = {"id": 1, "num": 42}
+    expected: Dict[str, Any] = {"id": 1, "num": 42}
     obj = Indexable(**expected)
-    obj.related = type(str("Related"), (object,), {"name": None})()
+    obj.related = type("Related", (object,), {"name": None})()
     expected["name"] = obj.related.name = "related name"
     obj.related.description = "description text"
     expected["text"] = obj.related.name + " " + obj.related.description
     doc = adapter.get_document(obj)
 
-    assert set(doc) == {"id", "name", "num", "text"}
+    assert set(doc) == {"id", "name", "num", "text", "object_type", "object_key"}
     assert doc["id"] == 1
     assert doc["num"] == 42
     assert doc["name"] == "related name"
