@@ -1,35 +1,38 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import shutil
+import typing
 import weakref
 from pathlib import Path
-from typing import Any, Optional, Text
+from typing import IO, Any, Dict, Optional, Set, Union
 from uuid import UUID, uuid1
 
 import sqlalchemy as sa
 import sqlalchemy.event
 from flask import _app_ctx_stack
 from flask.globals import _lookup_app_object
-from six import text_type
-from sqlalchemy.orm.session import Session
+from sqlalchemy.engine.base import Connection
+from sqlalchemy.orm.session import Session, SessionTransaction
+from sqlalchemy.orm.unitofwork import UOWTransaction
 
 from abilian.core.extensions import db
+from abilian.core.models import Model
+from abilian.core.models.blob import Blob
 from abilian.services import Service, ServiceState
 
+if typing.TYPE_CHECKING:
+    from abilian.app import Application
+
 _NULL_MARK = object()
 
 
-def _assert_uuid(uuid):
+def _assert_uuid(uuid: Any) -> None:
     if not isinstance(uuid, UUID):
         raise ValueError("Not an uuid.UUID instance", uuid)
 
 
 class RepositoryServiceState(ServiceState):
     #: :class:`Path` path to application repository
-    path = None  # type: Path
+    path: Optional[Path] = None
 
 
 class RepositoryService(Service):
@@ -38,10 +41,10 @@ class RepositoryService(Service):
     name = "repository"
     AppStateClass = RepositoryServiceState
 
-    def init_app(self, app):
-        Service.init_app(self, app)
+    def init_app(self, app: "Application") -> None:
+        super().init_app(app)
 
-        path = app.DATA_DIR / "files"
+        path = app.data_dir / "files"
         if not path.exists():
             path.mkdir(mode=0o775, parents=True)
 
@@ -49,8 +52,7 @@ class RepositoryService(Service):
             self.app_state.path = path.resolve()
 
     # data management: paths and accessors
-    def rel_path(self, uuid):
-        # type: (UUID) -> Path
+    def rel_path(self, uuid: UUID) -> Path:
         """Contruct relative path from repository top directory to the file
         named after this uuid.
 
@@ -60,8 +62,7 @@ class RepositoryService(Service):
         filename = str(uuid)
         return Path(filename[0:2], filename[2:4], filename)
 
-    def abs_path(self, uuid):
-        # type: (UUID) -> Path
+    def abs_path(self, uuid: UUID) -> Path:
         """Return absolute :class:`Path` object for given uuid.
 
         :param:uuid: :class:`UUID` instance
@@ -72,8 +73,7 @@ class RepositoryService(Service):
         assert top in dest.parents
         return dest
 
-    def get(self, uuid, default=None):
-        # type: (UUID, Optional[Path]) -> Optional[Path]
+    def get(self, uuid: UUID, default: Optional[Path] = None) -> Optional[Path]:
         """Return absolute :class:`Path` object for given uuid, if this uuid
         exists in repository, or `default` if it doesn't.
 
@@ -84,8 +84,7 @@ class RepositoryService(Service):
             return default
         return path
 
-    def set(self, uuid, content, encoding="utf-8"):
-        # type: (UUID, Any, Optional[Text]) -> None
+    def set(self, uuid: UUID, content: Any, encoding: str = "utf-8") -> None:
         """Store binary content with uuid as key.
 
         :param:uuid: :class:`UUID` instance
@@ -100,15 +99,14 @@ class RepositoryService(Service):
             content = content.read()
 
         mode = "tw"
-        if not isinstance(content, text_type):
+        if not isinstance(content, str):
             mode = "bw"
             encoding = None
 
         with dest.open(mode, encoding=encoding) as f:
             f.write(content)
 
-    def delete(self, uuid):
-        # type: (UUID) -> None
+    def delete(self, uuid: UUID) -> None:
         """Delete file with given uuid.
 
         :param:uuid: :class:`UUID` instance
@@ -120,19 +118,16 @@ class RepositoryService(Service):
 
         dest.unlink()
 
-    def __getitem__(self, uuid):
-        # type: (UUID) -> Any
+    def __getitem__(self, uuid: UUID) -> Path:
         value = self.get(uuid)
         if value is None:
             raise KeyError("No file can be found for this uuid", uuid)
         return value
 
-    def __setitem__(self, uuid, content):
-        # type: (UUID, Any) -> None
+    def __setitem__(self, uuid: UUID, content: Any) -> None:
         self.set(uuid, content)
 
-    def __delitem__(self, uuid):
-        # type: (UUID) -> None
+    def __delitem__(self, uuid: UUID) -> None:
         self.delete(uuid)
 
 
@@ -142,10 +137,10 @@ _REPOSITORY_TRANSACTION = "abilian_repository_transactions"
 
 
 class SessionRepositoryState(ServiceState):
-    path = None  # type: Path
+    path: Path
 
     @property
-    def transactions(self):
+    def transactions(self) -> Dict[int, Any]:
         try:
             return _lookup_app_object(_REPOSITORY_TRANSACTION)
         except AttributeError:
@@ -162,8 +157,7 @@ class SessionRepositoryState(ServiceState):
         setattr(top, _REPOSITORY_TRANSACTION, value)
 
     # transaction <-> db session accessors
-    def get_transaction(self, session):
-        # type: (Session) -> Optional[RepositoryTransaction]
+    def get_transaction(self, session: Session) -> Optional["RepositoryTransaction"]:
         if isinstance(session, sa.orm.scoped_session):
             session = session()
 
@@ -177,8 +171,9 @@ class SessionRepositoryState(ServiceState):
             transaction = None
         return transaction
 
-    def set_transaction(self, session, transaction):
-        # type: (Session, RepositoryTransaction) -> None
+    def set_transaction(
+        self, session: Session, transaction: "RepositoryTransaction"
+    ) -> None:
         """
         :param:session: :class:`sqlalchemy.orm.session.Session` instance
         :param:transaction: :class:`RepositoryTransaction` instance
@@ -189,8 +184,9 @@ class SessionRepositoryState(ServiceState):
         s_id = id(session)
         self.transactions[s_id] = (weakref.ref(session), transaction)
 
-    def create_transaction(self, session, transaction):
-        # type: (Session, RepositoryTransaction) -> None
+    def create_transaction(
+        self, session: Session, transaction: "RepositoryTransaction"
+    ) -> None:
         if not self.running:
             return
 
@@ -199,8 +195,9 @@ class SessionRepositoryState(ServiceState):
         transaction = RepositoryTransaction(root_path, parent)
         self.set_transaction(session, transaction)
 
-    def end_transaction(self, session, transaction):
-        # type: (Session, RepositoryTransaction) -> None
+    def end_transaction(
+        self, session: Session, transaction: "RepositoryTransaction"
+    ) -> None:
         if not self.running:
             return
 
@@ -212,19 +209,18 @@ class SessionRepositoryState(ServiceState):
                 tr.commit(session)
             self.set_transaction(session, tr._parent)
 
-    def begin(self, session):
+    def begin(self, session: Session) -> Optional[Any]:
         if not self.running:
-            return
+            return None
 
         tr = self.get_transaction(session)
         if tr is None:
             # FIXME: return or create a new one?
-            return
+            return None
 
         return tr.begin(session)
 
-    def commit(self, session):
-        # type: (Session) -> None
+    def commit(self, session: Session) -> None:
         if not self.running:
             return
 
@@ -234,14 +230,14 @@ class SessionRepositoryState(ServiceState):
 
         tr.commit(session)
 
-    def flush(self, session, flush_context):
+    def flush(self, session: Session, flush_context: UOWTransaction) -> None:
         # when sqlalchemy is flushing it is done in a sub-transaction,
         # not the root one. So when calling our 'commit' from here
         # we are not in our root transaction, so changes will not be
         # written to repository.
         self.commit(session)
 
-    def rollback(self, session):
+    def rollback(self, session: Session) -> None:
         if not self.running:
             return
 
@@ -262,12 +258,12 @@ class SessionRepositoryService(Service):
     name = "session_repository"
     AppStateClass = SessionRepositoryState
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         self.__listening = False
-        Service.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
-    def init_app(self, app):
-        Service.init_app(self, app)
+    def init_app(self, app: "Application") -> None:
+        super().init_app(app)
 
         path = Path(app.instance_path, "tmp", "files_transactions")
         if not path.exists():
@@ -279,7 +275,7 @@ class SessionRepositoryService(Service):
         if not self.__listening:
             self.start_listening()
 
-    def start_listening(self):
+    def start_listening(self) -> None:
         self.__listening = True
         listen = sa.event.listen
         listen(Session, "after_transaction_create", self.create_transaction)
@@ -290,7 +286,7 @@ class SessionRepositoryService(Service):
         listen(Session, "after_rollback", self.rollback)
         # appcontext_tearing_down.connect(self.clear_transaction, app)
 
-    def _session_for(self, model_or_session):
+    def _session_for(self, model_or_session: Union[Model, Session]) -> Session:
         """Return session instance for object parameter.
 
         If parameter is a session instance, it is return as is.
@@ -316,7 +312,11 @@ class SessionRepositoryService(Service):
         return session
 
     # repository interface
-    def get(self, session, uuid, default=None):
+    def get(
+        self, session: Union[Session, Blob], uuid: UUID, default: Any = None
+    ) -> Union[None, object, Path]:
+        # assert isinstance(session, Session)
+        # assert isinstance(uuid, UUID)
         session = self._session_for(session)
         transaction = self.app_state.get_transaction(session)
         try:
@@ -329,12 +329,18 @@ class SessionRepositoryService(Service):
 
         return val
 
-    def set(self, session, uuid, content, encoding="utf-8"):
+    def set(
+        self,
+        session: Union[Session, Blob],
+        uuid: UUID,
+        content: Union[IO, bytes, str],
+        encoding: str = "utf-8",
+    ) -> None:
         session = self._session_for(session)
         transaction = self.app_state.get_transaction(session)
         transaction.set(uuid, content, encoding)
 
-    def delete(self, session, uuid):
+    def delete(self, session: Union[Session, Blob], uuid: UUID) -> None:
         session = self._session_for(session)
         transaction = self.app_state.get_transaction(session)
         if self.get(session, uuid) is not None:
@@ -342,35 +348,43 @@ class SessionRepositoryService(Service):
 
     # session event handlers
     @Service.if_running
-    def create_transaction(self, session, transaction):
+    def create_transaction(
+        self, session: Session, transaction: SessionTransaction
+    ) -> Optional[Any]:
         return self.app_state.create_transaction(session, transaction)
 
     @Service.if_running
-    def end_transaction(self, session, transaction):
+    def end_transaction(
+        self, session: Session, transaction: SessionTransaction
+    ) -> Optional[Any]:
         return self.app_state.end_transaction(session, transaction)
 
     @Service.if_running
-    def begin(self, session, transaction, connection):
+    def begin(
+        self, session: Session, transaction: SessionTransaction, connection: Connection
+    ) -> Optional[Any]:
         return self.app_state.begin(session)
 
     @Service.if_running
-    def commit(self, session):
+    def commit(self, session: Session) -> None:
         return self.app_state.commit(session)
 
     @Service.if_running
-    def flush(self, session, flush_context):
+    def flush(self, session: Session, flush_context: UOWTransaction) -> None:
         return self.app_state.flush(session, flush_context)
 
     @Service.if_running
-    def rollback(self, session):
+    def rollback(self, session: Session) -> None:
         return self.app_state.rollback(session)
 
 
 session_repository = SessionRepositoryService()
 
 
-class RepositoryTransaction(object):
-    def __init__(self, root_path, parent=None):
+class RepositoryTransaction:
+    def __init__(
+        self, root_path: Path, parent: Optional["RepositoryTransaction"] = None
+    ) -> None:
         self.path = root_path / str(uuid1())
         # if parent is not None and parent.cleared:
         #   parent = None
@@ -381,14 +395,14 @@ class RepositoryTransaction(object):
         self.__cleared = False
 
     @property
-    def cleared(self):
+    def cleared(self) -> bool:
         return self.__cleared
 
-    def __del__(self):
+    def __del__(self) -> None:
         if not self.cleared:
             self._clear()
 
-    def _clear(self):
+    def _clear(self) -> None:
         if self.__cleared:
             return
 
@@ -401,14 +415,14 @@ class RepositoryTransaction(object):
         del self._set
         self.__cleared = True
 
-    def begin(self, session=None):
+    def begin(self, session: Optional[Session] = None) -> None:
         if not self.path.exists():
             self.path.mkdir(0o700)
 
-    def rollback(self, session=None):
+    def rollback(self, session: Optional[Session] = None) -> None:
         self._clear()
 
-    def commit(self, session=None):
+    def commit(self, session: Optional[Session] = None) -> None:
         """Merge modified objects into parent transaction.
 
         Once commited a transaction object is not usable anymore
@@ -425,7 +439,7 @@ class RepositoryTransaction(object):
             self._commit_repository()
         self._clear()
 
-    def _commit_repository(self):
+    def _commit_repository(self) -> None:
         assert self._parent is None
 
         for uuid in self._deleted:
@@ -438,8 +452,9 @@ class RepositoryTransaction(object):
             content = self.path / str(uuid)
             repository.set(uuid, content.open("rb"))
 
-    def _commit_parent(self):
+    def _commit_parent(self) -> None:
         p = self._parent
+        assert p
         p._deleted |= self._deleted
         p._deleted -= self._set
 
@@ -454,7 +469,7 @@ class RepositoryTransaction(object):
             # content_path.replace is not available with python < 3.3.
             content_path.rename(p.path / str(uuid))
 
-    def _add_to(self, uuid, dest, other):
+    def _add_to(self, uuid: UUID, dest: Set[UUID], other: Set[UUID]) -> None:
         """Add `item` to `dest` set, ensuring `item` is not present in `other`
         set."""
         _assert_uuid(uuid)
@@ -464,12 +479,12 @@ class RepositoryTransaction(object):
             pass
         dest.add(uuid)
 
-    def delete(self, uuid):
-        # type: (UUID) -> None
+    def delete(self, uuid: UUID) -> None:
         self._add_to(uuid, self._deleted, self._set)
 
-    def set(self, uuid, content, encoding="utf-8"):
-        # type: (UUID, Any, Optional[Text]) -> None
+    def set(
+        self, uuid: UUID, content: Union[IO, bytes, str], encoding: str = "utf-8"
+    ) -> None:
         self.begin()
         self._add_to(uuid, self._set, self._deleted)
 
@@ -486,10 +501,9 @@ class RepositoryTransaction(object):
         with dest.open(mode, encoding=encoding) as f:
             f.write(content)
 
-    def get(self, uuid):
-        # type: (UUID) -> Any
+    def get(self, uuid: UUID) -> Any:
         if uuid in self._deleted:
-            raise KeyError
+            raise KeyError(uuid)
 
         if uuid in self._set:
             path = self.path / str(uuid)
