@@ -1,12 +1,9 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import uuid
 from pathlib import Path
 
 from pytest import raises
+from sqlalchemy.orm import Session
 
 from . import repository
 
@@ -14,7 +11,7 @@ UUID_STR = "4f80f02f-52e3-4fe2-b9f2-2c3e99449ce9"
 UUID = uuid.UUID(UUID_STR)
 
 
-def test_rel_path(session):
+def test_rel_path(session: Session) -> None:
     with raises(ValueError):
         repository.rel_path(UUID_STR)
 
@@ -24,7 +21,7 @@ def test_rel_path(session):
     assert p == expected
 
 
-def test_abs_path(session):
+def test_abs_path(session: Session) -> None:
     with raises(ValueError):
         repository.abs_path(UUID_STR)
 
@@ -37,7 +34,7 @@ def test_abs_path(session):
     # self.assertEquals(p, expected)
 
 
-def test_get(session):
+def test_get(session: Session) -> None:
     with raises(ValueError):
         repository.get(UUID_STR)
 
@@ -69,14 +66,14 @@ def test_get(session):
         assert repository[u]
 
 
-def test_set(session):
+def test_set(session: Session) -> None:
     u1 = uuid.uuid4()
     p = repository.abs_path(u1)
     repository.set(u1, b"my file content")
     assert p.open("rb").read() == b"my file content"
 
 
-def test_setitem(session):
+def test_setitem(session: Session) -> None:
     u1 = uuid.uuid4()
     p = repository.abs_path(u1)
     repository[u1] = b"my file content"
@@ -84,7 +81,7 @@ def test_setitem(session):
     # FIXME: test Unicode content
 
 
-def test_delete(session):
+def test_delete(session: Session) -> None:
     u1 = uuid.uuid4()
     repository.set(u1, b"my file content")
     p = repository.abs_path(u1)
@@ -94,7 +91,7 @@ def test_delete(session):
     assert not p.exists()
 
 
-def test_delitem(session):
+def test_delitem(session: Session) -> None:
     u1 = uuid.uuid4()
     repository.set(u1, b"my file content")
     p = repository.abs_path(u1)
@@ -104,7 +101,7 @@ def test_delitem(session):
     assert not p.exists()
 
 
-def test_delete_non_existent(session):
+def test_delete_non_existent(session: Session) -> None:
     # non-existent
     u1 = uuid.uuid4()
     with raises(KeyError):
