@@ -1,19 +1,14 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
 
 
-class Taggable(object):
+class Taggable:
     """Mixin trait for taggable objects.
 
     Currently not used.
     """
 
-    pass
 
-
-class TagService(object):
+class TagService:
     """The tag service."""
 
     def tag(self, obj, term, user=None):
