@@ -1,17 +1,14 @@
-# coding=utf-8
 """Elements to build test cases for an :class:`abilian.app.Application`"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
-from typing import ContextManager
+from typing import ContextManager, List
 
 from flask.testing import FlaskClient
-from flask_login import current_user, login_user, logout_user
+from flask_login import login_user, logout_user
 from hyperlink import URL
-from six import text_type
 from sqlalchemy.exc import DatabaseError
 
+from abilian.app import Application
 from abilian.core.models.subjects import User
+from abilian.core.sqlalchemy import SQLAlchemy
 from abilian.services import get_service
 from abilian.web import url_for
 
@@ -26,7 +23,7 @@ __all__ = (
 
 
 def path_from_url(url):
-    url = text_type(url)
+    url = str(url)
     return "/" + "/".join(URL.from_text(url).path)
 
 
@@ -39,7 +36,7 @@ def client_login(client, user):
     # assert current_user.is_authenticated
     # assert current_user.id == user.id
 
-    class LoginContext(object):
+    class LoginContext:
         def __enter__(self):
             return None
 
@@ -68,7 +65,7 @@ def login(user, remember=False, force=False):
     if not success:
         raise ValueError("User is not active, cannot login; or use force=True")
 
-    class LoginContext(object):
+    class LoginContext:
         def __enter__(self):
             return None
 
@@ -78,7 +75,7 @@ def login(user, remember=False, force=False):
     return LoginContext()
 
 
-def cleanup_db(db):
+def cleanup_db(db: SQLAlchemy) -> None:
     """Drop all the tables, in a way that doesn't raise integrity errors."""
 
     # Need to run this sequence twice for some reason
@@ -88,7 +85,7 @@ def cleanup_db(db):
     db.drop_all()
 
 
-def _delete_tables(db):
+def _delete_tables(db: SQLAlchemy) -> None:
     for table in reversed(db.metadata.sorted_tables):
         try:
             db.session.execute(table.delete())
@@ -96,14 +93,14 @@ def _delete_tables(db):
             pass
 
 
-def ensure_services_started(services):
+def ensure_services_started(services: List[str]) -> None:
     for service_name in services:
         service = get_service(service_name)
         if not service.running:
             service.start()
 
 
-def stop_all_services(app):
+def stop_all_services(app: Application) -> None:
     for service in app.services.values():
         if service.running:
             service.stop()
