@@ -1,7 +1,5 @@
-# coding=utf-8
 """This package contains various modules that should be generic and reused in
 web application, specially CRM-like applications."""
-from __future__ import absolute_import, division, print_function
 
 from .util import url_for
 
