@@ -1,16 +1,14 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import logging
 import re
-from typing import Optional
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from flask import current_app, g
+from flask.app import Flask
 from flask.signals import appcontext_pushed
-from jinja2 import Markup, Template
-from six import python_2_unicode_compatible, string_types, text_type
+from flask_babel.speaklater import LazyString
+from jinja2 import Template
+from markupsafe import Markup
 
 from abilian.core.singleton import UniqueName
 from abilian.web import csrf
@@ -20,9 +18,13 @@ log = logging.getLogger(__name__)
 
 __all__ = (
     "Action",
+    "ActionDropDown",
+    "ActionGroup",
+    "ActionGroupItem",
     "ButtonAction",
     "FAIcon",
     "DynamicIcon",
+    "StaticIcon",
     "ModalActionMixin",
     "Endpoint",
     "actions",
@@ -46,7 +48,7 @@ ACTIVE = Status("active")
 DISABLED = Status("disabled")
 
 
-def getset(f):
+def getset(f: Callable) -> property:
     """Shortcut for a custom getter/ standard setter.
 
     Usage::
@@ -69,26 +71,25 @@ def getset(f):
     return property(f, f)
 
 
-@python_2_unicode_compatible
-class Icon(object):
+class Icon:
     """Base abstract class for icons."""
 
     def __html__(self):
         raise NotImplementedError
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.__html__()
 
 
 class NamedIconBase(Icon):
     """Renders markup for named icons set."""
 
-    template = None  # type: Optional[Template]
+    template: Template
 
-    def __init__(self, name=""):
+    def __init__(self, name: str = "") -> None:
         self.name = name
 
-    def __html__(self):
+    def __html__(self) -> str:
         return self.template.render(name=self.name)
 
 
@@ -129,7 +130,7 @@ class FAIconStacked(NamedIconBase):
         if "fa-stack-" not in second:
             second += " fa-stack-1x"
 
-        super(FAIconStacked, self).__init__(name)
+        super().__init__(name)
         self.second = second
         self.stack = stack
 
@@ -148,14 +149,14 @@ class DynamicIcon(Icon):
 
     def __init__(
         self,
-        endpoint=None,
-        width=12,
-        height=12,
-        css="",
-        size=None,
-        url_args=None,
-        **fixed_url_args
-    ):
+        endpoint: Optional[Union[str, Callable]] = None,
+        width: int = 12,
+        height: int = 12,
+        css: str = "",
+        size: Optional[int] = None,
+        url_args: Optional[Callable] = None,
+        **fixed_url_args,
+    ) -> None:
         self.endpoint = endpoint
         self.css = css
         self.fixed_url_args = {}
@@ -168,12 +169,12 @@ class DynamicIcon(Icon):
         self.width = width
         self.height = height
 
-    def get_url_args(self):
+    def get_url_args(self) -> Dict[str, str]:
         kw = {}
         kw.update(self.fixed_url_args)
         return kw
 
-    def __html__(self):
+    def __html__(self) -> str:
         endpoint = self.endpoint
         if callable(endpoint):
             endpoint = endpoint()
@@ -197,23 +198,28 @@ class StaticIcon(DynamicIcon):
     """
 
     def __init__(
-        self, filename, endpoint="static", width=12, height=12, css="", size=None
-    ):
+        self,
+        filename: str,
+        endpoint: str = "static",
+        width: int = 12,
+        height: int = 12,
+        css: str = "",
+        size: Optional[int] = None,
+    ) -> None:
         DynamicIcon.__init__(
             self, endpoint, width, height, css, size, filename=filename
         )
 
 
-@python_2_unicode_compatible
-class Endpoint(object):
+class Endpoint:
 
     # FIXME: *args doesn't seem to be relevant.
-    def __init__(self, name, *args, **kwargs):
+    def __init__(self, name: str, *args: Any, **kwargs: Any) -> None:
         self.name = name
         self.args = args
         self.kwargs = kwargs
 
-    def get_kwargs(self):
+    def get_kwargs(self) -> Dict[str, str]:
         """Hook for subclasses.
 
         The key and values in the returned dictionnary can be safely
@@ -222,10 +228,10 @@ class Endpoint(object):
         """
         return self.kwargs.copy()
 
-    def __str__(self):
-        return text_type(url_for(self.name, **self.get_kwargs()))
+    def __str__(self) -> str:
+        return str(url_for(self.name, **self.get_kwargs()))
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "{cls}({name!r}, *{args!r}, **{kwargs!r})".format(
             cls=self.__class__.__name__,
             name=self.name,
@@ -234,27 +240,17 @@ class Endpoint(object):
         )
 
 
-class Action(object):
+class Action:
     """Action interface."""
 
     Endpoint = Endpoint
-    category = None
-    name = None
-    title = None
-    description = None
-    icon = None
+
+    # title = None
+    # description = None
+    # icon = None
     _url = None
     CSS_CLASS = "action action-{category} action-{category}-{name}"
 
-    #: A :class:`Endpoint` instance, a string for a simple endpoint, a tuple
-    #: ``(endpoint_name, kwargs)``  or a callable which accept a : context dict
-    #: and returns one of those a valid values.
-    endpoint = None
-
-    #: A boolean (or something that can be converted to boolean), or a callable
-    #: which accepts a context dict as parameter. See :meth:`available`.
-    condition = None
-
     template_string = (
         '<a class="{{ action.css_class }}" href="{{ url }}">'
         "{%- if action.icon %}{{ action.icon }} {% endif %}"
@@ -264,21 +260,29 @@ class Action(object):
 
     def __init__(
         self,
-        category,
-        name,
-        title=None,
-        description=None,
-        icon=None,
-        url=None,
-        endpoint=None,
-        condition=None,
-        status=None,
-        template=None,
-        template_string=None,
-        button=None,
-        css=None,
-    ):
+        category: str,
+        name: str,
+        title: Union[LazyString, str] = "",
+        description: str = "",
+        icon: Union[str, Icon, None] = None,
+        url: Union[str, Callable] = "",
+        endpoint: Optional[Endpoint] = None,
+        condition: Optional[Callable] = None,
+        status: Optional[Any] = None,
+        template: Optional[Any] = None,
+        template_string: Optional[Any] = None,
+        button: Optional[Any] = None,
+        css: Optional[Any] = None,
+    ) -> None:
         """
+        :param endpoint: A :class:`Endpoint` instance, a string for a simple
+        endpoint, a tuple ``(endpoint_name, kwargs)`` or a callable which
+        accepts a : context dict and returns one of those a valid values.
+
+        :param condition: A boolean (or something that can be converted
+        to boolean), or a callable which accepts a context dict as parameter.
+        See :meth:`available`.
+
         :param button: if not `None`, a valid `btn` class (i.e `default`,
         `primary`...)
 
@@ -293,21 +297,21 @@ class Action(object):
         self.name = name
 
         if button is not None:
-            self.CSS_CLASS += " btn btn-{}".format(button)
+            self.CSS_CLASS += f" btn btn-{button}"
         if css is not None:
             self.CSS_CLASS = self.CSS_CLASS + " " + css
         self._build_css_class()
 
         self._title = title
         self._description = description
-        if isinstance(icon, string_types):
+        if isinstance(icon, str):
             icon = Glyphicon(icon)
         self._icon = icon
         self._url = url
         self._status = Status(status) if status is not None else ENABLED
         self._endpoint = endpoint
         if not callable(endpoint) and not isinstance(endpoint, Endpoint):
-            # property getter will make it and Endpoint instance
+            # property getter will make it an Endpoint instance
             self.endpoint = self.endpoint
         self.condition = condition
 
@@ -326,14 +330,14 @@ class Action(object):
 
     #: Boolean. Disabled actions are unconditionnaly skipped.
     @getset
-    def enabled(self, value=None):
+    def enabled(self, value: Optional[bool] = None) -> bool:
         enabled = self._enabled
         if value is not None:
             assert isinstance(value, bool)
             self._enabled = enabled = value
         return enabled
 
-    def _get_and_call(self, attr):
+    def _get_and_call(self, attr: str) -> Any:
         attr = "_" + attr
         value = getattr(self, attr)
         if callable(value):
@@ -341,14 +345,14 @@ class Action(object):
         return value
 
     @property
-    def title(self):
+    def title(self) -> Union[LazyString, str]:
         return self._get_and_call("title")
 
     @title.setter
-    def title(self, title):
+    def title(self, title: Union[LazyString, str]):
         self._title = title
 
-    def _build_css_class(self):
+    def _build_css_class(self) -> None:
         css_cat = self.CSS_CLASS.format(
             action=self, category=self.category, name=self.name
         )
@@ -356,15 +360,15 @@ class Action(object):
         self.css_class = css_cat
 
     @property
-    def description(self):
+    def description(self) -> Union[LazyString, str]:
         return self._get_and_call("description")
 
     @description.setter
-    def description(self, description):
+    def description(self, description: Union[LazyString, str]):
         self._description = description
 
     @property
-    def icon(self):
+    def icon(self) -> Icon:
         return self._get_and_call("icon")
 
     @icon.setter
@@ -372,32 +376,30 @@ class Action(object):
         self._icon = icon
 
     @property
-    def endpoint(self):
+    def endpoint(self) -> Optional[Endpoint]:
         endpoint = self._get_and_call("endpoint")
         if endpoint is None:
-            return
+            return None
 
         if not isinstance(endpoint, Endpoint):
-            if isinstance(endpoint, string_types):
+            if isinstance(endpoint, str):
                 endpoint = self.Endpoint(endpoint)
             elif isinstance(endpoint, (tuple, list)):
                 assert len(endpoint) == 2
                 endpoint, kwargs = endpoint
-                assert isinstance(endpoint, string_types)
+                assert isinstance(endpoint, str)
                 assert isinstance(kwargs, dict)
                 endpoint = self.Endpoint(endpoint, **kwargs)
             else:
-                raise ValueError(
-                    'Invalid endpoint specifier: "{}"'.format(repr(endpoint))
-                )
+                raise ValueError(f'Invalid endpoint specifier: "{repr(endpoint)}"')
 
         return endpoint
 
     @endpoint.setter
-    def endpoint(self, endpoint):
+    def endpoint(self, endpoint: Optional[Endpoint]) -> None:
         self._endpoint = endpoint
 
-    def available(self, context):
+    def available(self, context: Dict[str, Any]) -> bool:
         """Determine if this actions is available in this `context`.
 
         :param context: a dict whose content is left to application needs; if
@@ -408,10 +410,10 @@ class Action(object):
             return False
         try:
             return self.pre_condition(context) and self._check_condition(context)
-        except BaseException:
+        except Exception:
             return False
 
-    def pre_condition(self, context):
+    def pre_condition(self, context: Dict[str, Any]) -> bool:
         """Called by :meth:`.available` before checking condition.
 
         Subclasses may override it to ease creating actions with
@@ -420,7 +422,7 @@ class Action(object):
         """
         return True
 
-    def _check_condition(self, context):
+    def _check_condition(self, context: Dict[str, Any]) -> bool:
         if self.condition is None:
             return True
 
@@ -429,7 +431,7 @@ class Action(object):
         else:
             return bool(self.condition)
 
-    def render(self, **kwargs):
+    def render(self, **kwargs: Any) -> Markup:
         if not self.template:
             self.template = Template(self.template_string)
 
@@ -441,7 +443,7 @@ class Action(object):
         params = self.get_render_args(**kwargs)
         return Markup(template.render(params))
 
-    def get_render_args(self, **kwargs):
+    def get_render_args(self, **kwargs: Any) -> Dict[str, Any]:
         params = {"action": self}
         params.update(actions.context)
         params.update(kwargs)
@@ -449,17 +451,17 @@ class Action(object):
         params["url"] = self.url(params)
         return params
 
-    def url(self, context=None):
+    def url(self, context: Dict[str, Any] = None) -> str:
         if callable(self._url):
             return self._url(context)
 
-        endpoint = self.endpoint
-        if endpoint:
-            return text_type(endpoint)
+        if self.endpoint:
+            return str(self.endpoint)
+
         return self._url
 
 
-class ModalActionMixin(object):
+class ModalActionMixin:
     template_string = (
         '<a class="{{ action.css_class }}" href="{{ url }}" data-toggle="modal">'
         "{%- if action.icon %}{{ action.icon}} {% endif %}"
@@ -482,13 +484,13 @@ class ButtonAction(Action):
 
     def __init__(
         self,
-        category,
-        name,
-        submit_name="__action",
-        btn_class="default",
-        *args,
-        **kwargs
-    ):
+        category: str,
+        name: str,
+        submit_name: str = "__action",
+        btn_class: str = "default",
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         Action.__init__(self, category, name, *args, **kwargs)
         self.submit_name = submit_name
         self.btn_class = btn_class
@@ -506,11 +508,11 @@ class ActionGroup(Action):
     )
 
     def __init__(self, category, name, items=(), *args, **kwargs):
-        super(ActionGroup, self).__init__(category, name, *args, **kwargs)
+        super().__init__(category, name, *args, **kwargs)
         self.items = list(items)
 
     def get_render_args(self, **kwargs):
-        params = super(ActionGroup, self).get_render_args(**kwargs)
+        params = super().get_render_args(**kwargs)
         params["action_items"] = [a for a in self.items if a.available(params)]
         return params
 
@@ -542,11 +544,11 @@ class ActionGroupItem(Action):
     divider = False
 
     def __init__(self, category, name, divider=False, *args, **kwargs):
-        super(ActionGroupItem, self).__init__(category, name, *args, **kwargs)
+        super().__init__(category, name, *args, **kwargs)
         self.divider = divider
 
 
-class ActionRegistry(object):
+class ActionRegistry:
     """The Action registry.
 
     This is a Flask extension which registers :class:`.Action` sets. Actions are
@@ -559,7 +561,7 @@ class ActionRegistry(object):
 
     __EXTENSION_NAME = "abilian:actions"
 
-    def init_app(self, app):
+    def init_app(self, app: Flask) -> None:
         if self.__EXTENSION_NAME in app.extensions:
             log.warning(
                 "ActionRegistry.init_app: actions already enabled on this application"
@@ -570,17 +572,17 @@ class ActionRegistry(object):
         appcontext_pushed.connect(self._init_context, app)
 
         @app.context_processor
-        def add_registry_to_jinja_context():
+        def add_registry_to_jinja_context() -> Dict[str, ActionRegistry]:
             return {"actions": self}
 
-    def installed(self, app=None):
+    def installed(self, app: Optional[Flask] = None) -> bool:
         """Return `True` if the registry has been installed in current
         applications."""
         if app is None:
             app = current_app
         return self.__EXTENSION_NAME in app.extensions
 
-    def register(self, *actions):
+    def register(self, *actions: Any) -> None:
         """Register `actions` in the current application. All `actions` must be
         an instance of :class:`.Action` or one of its subclasses.
 
@@ -596,7 +598,7 @@ class ActionRegistry(object):
             reg = self._state["categories"].setdefault(cat, [])
             reg.append(action)
 
-    def actions(self, context=None):
+    def actions(self, context: Optional[Any] = None) -> Dict[str, Any]:
         """Return a mapping of category => actions list.
 
         Actions are filtered according to :meth:`.Action.available`.
@@ -613,7 +615,7 @@ class ActionRegistry(object):
             result[cat] = [a for a in actions if a.available(context)]
         return result
 
-    def for_category(self, category, context=None):
+    def for_category(self, category: str, context: Any = None) -> List[Action]:
         """Returns actions list for this category in current application.
 
         Actions are filtered according to :meth:`.Action.available`.
@@ -630,15 +632,15 @@ class ActionRegistry(object):
         return [a for a in actions if a.available(context)]
 
     @property
-    def _state(self):
+    def _state(self) -> Any:
         return current_app.extensions[self.__EXTENSION_NAME]
 
     @staticmethod
-    def _init_context(sender):
+    def _init_context(sender: Flask) -> None:
         g.action_context = {}
 
     @property
-    def context(self):
+    def context(self) -> Dict[str, bool]:
         """Return action context (dict type).
 
         Applications can modify it to suit their needs.
