@@ -1,10 +1,11 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from typing import TYPE_CHECKING, Any, Callable, Dict
+
+if TYPE_CHECKING:
+    from .extension import Admin
 
 
-class AdminPanel(object):
+class AdminPanel:
     """Base classe for admin panels.
 
     Currently this class does nothing. It may be useful in the future
@@ -13,11 +14,12 @@ class AdminPanel(object):
     will be removed.
     """
 
-    id = ""
-    label = ""
-    icon = ""
+    id: str = ""
+    label: str = ""
+    icon: str = ""
+    admin: "Admin"
 
-    def url_value_preprocess(self, endpoint, view_args):
+    def url_value_preprocess(self, endpoint: str, view_args: Dict[Any, Any]) -> None:
         """Panel can preprocess values for their views.
 
         This method is called only if the endpoint is for `get()`, `post()`, or
@@ -25,9 +27,8 @@ class AdminPanel(object):
 
         This is also the right place to add items to the breadcrumbs.
         """
-        pass
 
-    def install_additional_rules(self, add_url_rule):
+    def install_additional_rules(self, add_url_rule: Callable) -> None:
         """This method can be redefined in subclasses to install custom url
         rules.
 
@@ -37,4 +38,3 @@ class AdminPanel(object):
         :param add_url_rule: function to use to add url rules, same interface as
             :meth:`flask.blueprint.Blueprint.add_url_rule`.
         """
-        pass
