@@ -1,14 +1,9 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from datetime import datetime
 from itertools import chain
-from typing import Text
+from typing import Callable, Dict
 
 import pytz
-import six
 import sqlalchemy as sa
 import sqlalchemy.orm
 from flask import get_template_attribute, render_template, \
@@ -40,7 +35,7 @@ def format_date_for_input(date):
 class JSONUserSearch(JSONView):
     """Search users by fullname."""
 
-    def data(self, q, *args, **kwargs):
+    def data(self, q, *args, **kwargs) -> Dict:
         q = q.replace("%", " ").strip().lower()
 
         if not q or len(q) < 2:
@@ -67,15 +62,11 @@ class JSONUserSearch(JSONView):
 
         values = query.values(User.id, User.first_name, User.last_name, User.email)
         results = [
-            {
-                "id": obj.id,
-                "text": "{} {} ({})".format(obj.first_name, obj.last_name, obj.email),
-            }
+            {"id": obj.id, "text": f"{obj.first_name} {obj.last_name} ({obj.email})"}
             for obj in values
         ]
 
-        result = {"results": results}
-        return result
+        return {"results": results}
 
 
 class AuditPanel(AdminPanel):
@@ -91,10 +82,10 @@ class AuditPanel(AdminPanel):
     label = "Audit trail"
     icon = "list-alt"
 
-    def install_additional_rules(self, add_url_rule):
+    def install_additional_rules(self, add_url_rule: Callable) -> None:
         add_url_rule("/search_users", view_func=JSONUserSearch.as_view("search_users"))
 
-    def get(self):
+    def get(self) -> str:
         LIMIT = 30
 
         base_audit_q = AuditEntry.query
@@ -167,13 +158,11 @@ class AuditPanel(AdminPanel):
         )
         # audit_entries = []
         all_entries = sorted(
-            list(
-                chain(
-                    #
-                    (AuditEntryPresenter(e) for e in audit_entries),
-                    #
-                    (SecurityEntryPresenter(e) for e in security_entries),
-                )
+            chain(
+                #
+                (AuditEntryPresenter(e) for e in audit_entries),
+                #
+                (SecurityEntryPresenter(e) for e in security_entries),
             )
         )
 
@@ -257,7 +246,7 @@ class AuditPanel(AdminPanel):
 #
 #  Presenters for audit entries listing
 #
-class BaseEntryPresenter(object):
+class BaseEntryPresenter:
 
     _USER_FMT = (
         '<a href="{{ url_for("social.user", user_id=user.id) }}">' "{{ user.name }}</a>"
@@ -271,13 +260,6 @@ class BaseEntryPresenter(object):
         self.user = user
         self.date = local_dt(date)
 
-    if six.PY2:
-
-        def __cmp__(self, other):
-            # Python 3 compatibility. XXX: Really needed?
-            a, b = self.date, other.date
-            return (a > b) - (a < b)
-
     def __lt__(self, other):
         return self.date < other.date
 
@@ -290,21 +272,18 @@ class BaseEntryPresenter(object):
     def model(model_name):
         return db.Model._decl_class_registry.get(model_name)
 
-    def render(self):
-        # type: () -> Text
+    def render(self) -> str:
         raise NotImplementedError
 
 
 class AuditEntryPresenter(BaseEntryPresenter):
-    def __init__(self, entry):
-        # type: (AuditEntry) -> None
+    def __init__(self, entry: AuditEntry) -> None:
         assert isinstance(entry, AuditEntry)
-        super(AuditEntryPresenter, self).__init__(entry.user, entry.happened_at)
+        super().__init__(entry.user, entry.happened_at)
         self.entry = entry
         self.entity_deleted = entry.entity is None
 
-    def render(self):
-        # type: () -> Text
+    def render(self) -> str:
         render = render_template_string
         e = self.entry
         user = render(self._USER_FMT, user=e.user)
@@ -331,7 +310,7 @@ class AuditEntryPresenter(BaseEntryPresenter):
         elif e.op == 2:
             msg = _('{user} has deleted {entity_type}: {entity_id} "{entity}"')
         else:
-            raise Exception("Bad entry type: {}".format(e.type))
+            raise Exception(f"Bad entry type: {e.type}")
 
         self.msg = Markup(
             msg.format(
@@ -346,14 +325,12 @@ class AuditEntryPresenter(BaseEntryPresenter):
 
 
 class SecurityEntryPresenter(BaseEntryPresenter):
-    def __init__(self, entry):
-        # type: (SecurityAudit) -> None
+    def __init__(self, entry: SecurityAudit) -> None:
         assert isinstance(entry, SecurityAudit)
-        super(SecurityEntryPresenter, self).__init__(entry.manager, entry.happened_at)
+        super().__init__(entry.manager, entry.happened_at)
         self.entry = entry
 
-    def render(self):
-        # type: () -> Text
+    def render(self) -> str:
         render = render_template_string
         e = self.entry
 
@@ -402,14 +379,14 @@ class SecurityEntryPresenter(BaseEntryPresenter):
                     "{principal} on {entity}"
                 )
             else:
-                raise Exception("Invalid entity op: {}".format(e.op))
+                raise Exception(f"Invalid entity op: {e.op}")
         else:
             if e.op == e.GRANT:
                 msg = _('{manager} has given role "{role}" to {principal}')
             elif e.op == e.REVOKE:
                 msg = _('{manager} has revoked role "{role}" from {principal}')
             else:
-                raise Exception("Invalid entity op: {}".format(e.op))
+                raise Exception(f"Invalid entity op: {e.op}")
 
         self.msg = Markup(
             msg.format(manager=manager, principal=principal, role=e.role, entity=entity)
