@@ -1,8 +1,4 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from wtforms.fields import BooleanField, StringField
 
 from abilian.i18n import _l
