@@ -1,37 +1,40 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from datetime import timedelta
+from typing import Optional
 
 from flask import current_app, flash, redirect, render_template, request, \
     url_for
 from flask_babel import gettext as _
 from flask_babel import lazy_gettext as _l
+from flask_babel.speaklater import LazyString
 from jinja2 import Template
 
 from abilian.core.extensions import db
 from abilian.services import get_service
 from abilian.web import csrf
-
-from ..panel import AdminPanel
+from abilian.web.admin import AdminPanel
 
 
-class Key(object):
+class Key:
 
     template = Template(
         '<input type="text" class="form-control" '
         'name="{{ key.id }}" value="{{ config[key.id] }}" />'
     )
 
-    def __init__(self, id, type_, label=None, description=None):
+    def __init__(
+        self,
+        id: str,
+        type_: str,
+        label: Optional[LazyString] = None,
+        description: Optional[LazyString] = None,
+    ) -> None:
         self.id = id
         self.type = type_
         self.label = label
         self.description = description
 
-    def __html__(self):
+    def __html__(self) -> str:
         return render_template(self.template, key=self, config=current_app.config)
 
     def value_from_request(self):
@@ -42,9 +45,8 @@ class SessionLifeTimeKey(Key):
 
     template = "admin/settings_session_lifetime.html"
 
-    def __init__(self):
-        Key.__init__(
-            self,
+    def __init__(self) -> None:
+        super().__init__(
             "PERMANENT_SESSION_LIFETIME",
             "timedelta",
             label=_l("Session lifetime"),
@@ -62,18 +64,13 @@ class SessionLifeTimeKey(Key):
 
         if (days + hours) == 0 and minutes < 10:
             # avoid dummy sessions durations: minimum is 10 minutes
-            flash(
-                _(
-                    "Minimum session lifetime is 10 minutes. "
-                    "Value has been adjusted."
-                ),
-                "warning",
-            )
+            msg = _("Minimum session lifetime is 10 minutes. Value has been adjusted.")
+            flash(msg, "warning")
             minutes = 10
 
         return timedelta(days=days, hours=hours, minutes=minutes)
 
-    def _get_current(self, field):
+    def _get_current(self, field: str) -> int:
         td = current_app.config.get(self.id)
         if td:
             if field == "days":
@@ -85,15 +82,15 @@ class SessionLifeTimeKey(Key):
         return 0
 
     @property
-    def days(self):
+    def days(self) -> int:
         return self._get_current("days")
 
     @property
-    def hours(self):
+    def hours(self) -> int:
         return self._get_current("hours")
 
     @property
-    def minutes(self):
+    def minutes(self) -> int:
         return self._get_current("minutes")
 
 
@@ -118,7 +115,7 @@ class SettingsPanel(AdminPanel):
     def settings(self):
         return get_service("settings").namespace("config")
 
-    def get(self):
+    def get(self) -> str:
         return render_template("admin/settings.html", keys=self._keys)
 
     @csrf.protect
