@@ -1,9 +1,6 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
 
-from flask import current_app
+from flask import Flask, current_app
 from flask_login import current_user
 
 from abilian.core.models import attachment as attachments
@@ -17,13 +14,13 @@ from .views import bp as blueprint
 _MANAGER_ATTR = "__attachments_manager__"
 
 
-class AttachmentExtension(object):
+class AttachmentExtension:
     """API for comments, installed as an application extension.
 
     It is also available in templates as `attachments`.
     """
 
-    def __init__(self, app):
+    def __init__(self, app: Flask) -> None:
         app.extensions["attachments"] = self
         app.add_template_global(self, "attachments")
         app.register_blueprint(blueprint)
@@ -62,7 +59,7 @@ class AttachmentExtension(object):
 _DEFAULT_TEMPLATE = "macros/attachment_default.html"
 
 
-class AttachmentsManager(object):
+class AttachmentsManager:
     """Allow customization of attachments form, display macros, etc.
 
     can be used as class decorator
