@@ -1,7 +1,6 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+
+from flask import Flask
 
 from abilian.core.models import comment as comments
 from abilian.web import url_for
@@ -11,13 +10,13 @@ from .views import COMMENT_BUTTON
 from .views import bp as blueprint
 
 
-class CommentExtension(object):
+class CommentExtension:
     """API for comments, installed as an application extension.
 
     It is also available in templates as `comments`.
     """
 
-    def __init__(self, app):
+    def __init__(self, app: Flask) -> None:
         app.extensions["comments"] = self
         app.add_template_global(self, "comments")
         app.register_blueprint(blueprint)
