@@ -1,27 +1,24 @@
-# coding=utf-8
-
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from functools import wraps
+from typing import Callable
 
-from flask import Blueprint, current_app, jsonify, request
+from flask import Blueprint, current_app, request
 from flask_wtf import Form as FlaskForm
 from werkzeug.exceptions import Forbidden
+from wtforms.ext.csrf.fields import CSRFTokenField
 
 blueprint = Blueprint("csrf", __name__, url_prefix="/csrf")
 
 
 @blueprint.route("/token", endpoint="json_token")
 def json_token_view():
-    return jsonify(token=token())
+    return {"token": token()}
 
 
-def field():
+def field() -> CSRFTokenField:
     """Return an instance of `wtforms.ext.csrf.fields.CSRFTokenField`, suitable
     for rendering.
 
-    Renders an empty string if `config.CSRF_ENABLED` is not set.
+    Renders an empty string if `config.WTF_CSRF_ENABLED` is not set.
     """
     return FlaskForm().csrf_token
 
@@ -31,7 +28,7 @@ def time_limit():
     return current_app.config.get("WTF_CSRF_TIME_LIMIT", 3600)
 
 
-def name():
+def name() -> str:
     """Field name expected to have CSRF token.
 
     Useful for passing it to JavaScript for instance.
@@ -39,7 +36,7 @@ def name():
     return "csrf_token"
 
 
-def token():
+def token() -> str:
     """Value of current csrf token.
 
     Useful for passing it to JavaScript for instance.
@@ -47,7 +44,7 @@ def token():
     return field().current_token or ""
 
 
-def support_graceful_failure(view):
+def support_graceful_failure(view: Callable) -> Callable:
     """Decorator to indicate that the view will handle itself the csrf failure.
 
     View can be a view function or a class based view
@@ -60,9 +57,9 @@ def has_failed():
     return getattr(request, "csrf_failed", False)
 
 
-def protect(view):
+def protect(view: Callable) -> Callable:
     """Protects a view agains CSRF attacks by checking `csrf_token` value in
-    submitted values. Do nothing if `config.CSRF_ENABLED` is not set.
+    submitted values. Do nothing if `config.WTF_CSRF_ENABLED` is not set.
 
     Raises `werkzeug.exceptions.Forbidden` if validation fails.
     """
