@@ -1,9 +1,5 @@
-# -*- coding: utf-8 -*-
 """View decorators for controlling some aspect of HTTP, mainly: Cache
 headers."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from functools import wraps
 
 from flask import make_response
