@@ -1,32 +1,38 @@
-# coding=utf-8
 """Navigation elements.
 
 Abilian define theses categories:   `section`:     Used for navigation
 elements relevant to site section   `user`:     User for element that
 should appear in user menu
 """
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+import typing
+from typing import Any, Dict, Optional, Tuple, Union
 
 from flask import g
+from flask_babel.speaklater import LazyString
 from jinja2 import Markup, Template
-from six import string_types, text_type
+
+from abilian.web.action import Endpoint
 
 from .action import ACTIVE, ENABLED, Action, Glyphicon, getset
 
+if typing.TYPE_CHECKING:
+    from abilian.web.action import Status
+
 
 class NavItem(Action):
     """A single navigation item."""
 
     divider = False
 
-    def __init__(self, category, name, divider=False, *args, **kwargs):
+    def __init__(
+        self, category: str, name: str, divider: bool = False, *args: Any, **kwargs: Any
+    ) -> None:
         category = "navigation:" + category
-        Action.__init__(self, category, name, *args, **kwargs)
+        super().__init__(category, name, *args, **kwargs)
         self.divider = divider
 
     @getset
-    def status(self, value=None):
+    def status(self, value: Optional[Any] = None) -> "Status":
         current = g.nav.get("active")
         if current is None:
             return ENABLED
@@ -38,7 +44,7 @@ class NavItem(Action):
         return status
 
     @property
-    def path(self):
+    def path(self) -> str:
         return self.category + ":" + self.name
 
 
@@ -62,28 +68,30 @@ class NavGroup(NavItem):
     </ul>
     """
 
-    def __init__(self, category, name, items=(), *args, **kwargs):
+    def __init__(
+        self, category: str, name: str, items: Tuple[()] = (), *args: Any, **kwargs: Any
+    ) -> None:
         NavItem.__init__(self, category, name, *args, **kwargs)
         self.items = list(items)
         self._paths = {self.path}
         for i in self.items:
             self._paths.add(i.path)
 
-    def append(self, item):
+    def append(self, item: NavItem) -> None:
         self.items.append(item)
         self._paths.add(item.path)
 
-    def insert(self, pos, item):
+    def insert(self, pos: int, item: NavItem) -> None:
         self.items.insert(pos, item)
         self._paths.add(item.path)
 
-    def get_render_args(self, **kwargs):
-        params = super(NavGroup, self).get_render_args(**kwargs)
+    def get_render_args(self, **kwargs: Any) -> Dict[str, Any]:
+        params = super().get_render_args(**kwargs)
         params["action_items"] = [a for a in self.items if a.available(params)]
         return params
 
     @getset
-    def status(self, value=None):
+    def status(self, value: Optional[Any] = None) -> "Status":
         current = g.nav.get("active")
         if current is None:
             return ENABLED
@@ -94,7 +102,7 @@ class NavGroup(NavItem):
         return status
 
 
-class BreadcrumbItem(object):
+class BreadcrumbItem:
     """A breadcrumb element has at least a label or an icon."""
 
     #: Label shown to user. May be an i18n string instance
@@ -116,7 +124,13 @@ class BreadcrumbItem(object):
         "{%- if url %}</a>{%- endif %}"
     )
 
-    def __init__(self, label="", url="#", icon=None, description=None):
+    def __init__(
+        self,
+        label: Union[LazyString, str] = "",
+        url: Union[str, Endpoint] = "#",
+        icon: Optional[str] = None,
+        description: Optional[Any] = None,
+    ) -> None:
         # don't test 'label or...': if label is a lazy_gettext, it will be
         # resolved. If this item is created in a url_value_preprocessor, it will
         # setup i18n before auth has loaded user, so i18n will fallback on browser
@@ -124,7 +138,7 @@ class BreadcrumbItem(object):
         # the whole request.
         assert label is not None or icon is None
         self.label = label
-        if isinstance(icon, string_types):
+        if isinstance(icon, str):
             icon = Glyphicon(icon)
 
         self.icon = icon
@@ -133,8 +147,8 @@ class BreadcrumbItem(object):
         self.__template = Template(self.template_string)
 
     @property
-    def url(self):
-        return text_type(self._url)
+    def url(self) -> str:
+        return str(self._url)
 
-    def render(self):
+    def render(self) -> Markup:
         return Markup(self.__template.render(item=self, url=self.url))
