@@ -1,21 +1,18 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import imghdr
 from pathlib import Path
 
 from flask import request, url_for
 from flask_login import login_user
 
+from abilian.core.models.subjects import create_root_user
 from abilian.web.preferences.user import UserPreferencesForm
 
 AVATAR_COLORMAP = Path(__file__).parent / "avatar-colormap.png"
 
 
 def test_form_photo(app, db):
-    user = app.create_root_user()
+    user = create_root_user()
     url = url_for("preferences.user")
     uploads = app.extensions["uploads"]
     with AVATAR_COLORMAP.open("rb") as f:
