@@ -1,8 +1,4 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import imghdr
 from io import BytesIO
 
@@ -10,7 +6,6 @@ import babel.dates
 import PIL.Image
 from flask import current_app, flash, g, redirect, render_template, request, \
     url_for
-from six import PY2
 from werkzeug.exceptions import InternalServerError
 from wtforms.fields import StringField
 from wtforms.validators import ValidationError
@@ -20,6 +15,7 @@ from abilian.i18n import _, _l, get_default_locale
 from abilian.services.preferences.panel import PreferencePanel
 from abilian.web import csrf
 from abilian.web.forms import Form, fields, required, widgets
+from abilian.web.forms.fields import FileField
 
 
 class UserPreferencesForm(Form):
@@ -45,7 +41,7 @@ class UserPreferencesForm(Form):
         label=_l("Time zone"), validators=(required(),), default=babel.dates.LOCALTZ
     )
 
-    def validate_password(self, field):
+    def validate_password(self, field: StringField) -> None:
         pwd = field.data
         confirmed = self["confirm_password"].data
 
@@ -57,7 +53,7 @@ class UserPreferencesForm(Form):
                 )
             )
 
-    def validate_photo(self, field):
+    def validate_photo(self, field: FileField) -> None:
         data = request.form.get(field.name)
         if not data:
             return
@@ -79,7 +75,7 @@ class UserPreferencesForm(Form):
             # check this is actually an image file
             im = PIL.Image.open(data)
             im.load()
-        except BaseException:
+        except Exception:
             raise ValidationError(_("Could not decode image file"))
 
         # convert to jpeg
@@ -107,7 +103,7 @@ class UserPreferencesPanel(PreferencePanel):
             # subclass str/bytes to set additional 'url' attribute
 
             photo = type(
-                b"Photo" if PY2 else "Photo",
+                "Photo",
                 (bytes,),
                 {"object": photo, "url": url_for("users.photo", user_id=g.user.id)},
             )
