@@ -1,27 +1,28 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import logging
-from typing import Text, Union
+from typing import TYPE_CHECKING, Any, Optional, Tuple, Type
 
-from six import string_types
+from flask import Request
 from sqlalchemy import func, orm
 from sqlalchemy.sql.expression import or_
 
+from abilian.core.entities import EntityQuery
+from abilian.core.models import Model
+
+if TYPE_CHECKING:
+    from abilian.web.frontend import Module
+
 logger = logging.getLogger(__name__)
 
 
-class UNDEFINED(object):
+class UNDEFINED:
     pass
 
 
 _UNDEFINED = UNDEFINED()
 
 
-class BaseCriterion(object):
-    form_default_value = _UNDEFINED  # type: Union[UNDEFINED, Text]
+class BaseCriterion:
+    form_default_value: Any = _UNDEFINED
     """
     Values to set by default when adding a filter. The provided value(s) must be
     the ones used in html, not in python.
@@ -29,7 +30,9 @@ class BaseCriterion(object):
     Subclasses can also define property.
     """
 
-    def __init__(self, name, label="", form_default_value=_UNDEFINED):
+    def __init__(
+        self, name: str, label: str = "", form_default_value: Any = _UNDEFINED
+    ) -> None:
         self.name = name
         self.label = label
 
@@ -44,7 +47,7 @@ class BaseCriterion(object):
             raise ValueError("Model not set")
         return self._model
 
-    def _set_model(self, model):
+    def _set_model(self, model: Type[Model]) -> None:
         if self._model is not None:
             raise ValueError("Model already set")
 
@@ -76,20 +79,26 @@ class BaseCriterion(object):
         return self.form_default_value is not _UNDEFINED
 
     def __repr__(self):
-        return "<{} name={}>".format(self.__class__.__name__, self.name)
+        return f"<{self.__class__.__name__} name={self.name}>"
 
 
 class TextSearchCriterion(BaseCriterion):
     """Fulltext search on given attributes."""
 
-    def __init__(self, name, label="", attributes=None, search_fmt="%{q}%"):
-        super(TextSearchCriterion, self).__init__(name, label)
+    def __init__(
+        self,
+        name: str,
+        label: str = "",
+        attributes: Optional[Tuple[str, str]] = None,
+        search_fmt: str = "%{q}%",
+    ) -> None:
+        super().__init__(name, label)
         self.attributes = dict.fromkeys(
             attributes if attributes is not None else (name,)
         )
         self._attributes_prepared = False
 
-        if isinstance(search_fmt, string_types):
+        if isinstance(search_fmt, str):
             search_fmt = [search_fmt]
 
         self.search_fmt = search_fmt
@@ -132,7 +141,16 @@ class TextSearchCriterion(BaseCriterion):
 
         self._attributes_prepared = True
 
-    def filter(self, query, module, request, searched_text, *args, **kwargs):
+    def filter(
+        self,
+        query: EntityQuery,
+        module: "Module",
+        request: Request,
+        searched_text: str,
+        *args,
+        **kwargs,
+    ) -> EntityQuery:
+
         if not searched_text:
             return query
 
@@ -190,24 +208,24 @@ class TextSearchCriterion(BaseCriterion):
 
         return rel_model, attr
 
-    def is_excluded(self, attr_name, request):
+    def is_excluded(self, attr_name: str, request: Request):
         """To be overriden by subclasses that want to filter searched
         attributes."""
         return False
 
     @property
-    def has_form_filter(self):
+    def has_form_filter(self) -> bool:
         return False
 
 
 class TextCriterion(TextSearchCriterion):
     def __init__(self, name, label="", attributes=None, search_fmt="%{q}%"):
-        super(TextCriterion, self).__init__(name, label, attributes, search_fmt)
+        super().__init__(name, label, attributes, search_fmt)
 
     def filter(self, query, module, request, searched_text, *args, **kwargs):
         my_searched_text = request.values.get(self.name, "").strip()
         if my_searched_text:
-            return super(TextCriterion, self).filter(
+            return super().filter(
                 query, module, request, my_searched_text.lower(), *args, **kwargs
             )
         else:
