@@ -1,14 +1,11 @@
-# coding=utf-8
 """Admin panel for tags."""
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
-from typing import List
+from typing import Callable, List
 
 import sqlalchemy as sa
 import sqlalchemy.orm
-import sqlalchemy.sql.functions as func
 from flask import current_app, flash, redirect, render_template, request
+from sqlalchemy.sql import functions as func
 
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
@@ -68,7 +65,7 @@ class NSView(View):
     """View a Namespace."""
 
     def __init__(self, view_endpoint, *args, **kwargs):
-        super(NSView, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.__selected_tags = None
         self.view_endpoint = view_endpoint
 
@@ -112,8 +109,7 @@ class NSView(View):
             flash(_("Unknown action"))
             self.get(self.ns)
 
-    def _get_selected_tags(self):
-        # type: () -> List[Tag]
+    def _get_selected_tags(self) -> List[Tag]:
 
         if self.__selected_tags is None:
             tag_ids = request.form.getlist("selected", type=int)
@@ -208,19 +204,19 @@ class NSView(View):
         return self.redirect_to_view()
 
 
-class BaseTagView(object):
+class BaseTagView:
     """Mixin for tag views."""
 
     Model = Tag
     Form = TagForm
 
     def __init__(self, *args, **kwargs):
-        super(BaseTagView, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.extension = current_app.extensions["tags"]
 
     def prepare_args(self, args, kwargs):
         self.ns = kwargs.pop("ns")
-        return super(BaseTagView, self).prepare_args(args, kwargs)
+        return super().prepare_args(args, kwargs)
 
     def view_url(self):
         return url_for(".tags_ns", ns=self.ns)
@@ -231,7 +227,7 @@ class BaseTagView(object):
 class TagEdit(BaseTagView, ObjectEdit):
     _message_success = _l("Tag edited")
     has_changes = False
-    _entities_to_reindex = []  # type: List[Entity]
+    _entities_to_reindex: List[Entity] = []
 
     def after_populate_obj(self):
         session = sa.orm.object_session(self.obj)
@@ -279,7 +275,7 @@ class TagPanel(AdminPanel):
 
         return render_template("admin/tags.html", namespaces=namespaces)
 
-    def install_additional_rules(self, add_url_rule):
+    def install_additional_rules(self, add_url_rule: Callable) -> None:
         panel_endpoint = "." + self.id
         ns_base = "/<string:ns>/"
         add_url_rule(
