@@ -1,11 +1,7 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from typing import Any
 
-import six
+from flask import Flask
 
 from abilian.core.entities import Entity
 from abilian.core.models.tag import TAGS_ATTR, Tag, supports_tagging
@@ -46,18 +42,16 @@ class _TagsForm(Form):
         if obj is not None:
             tags = getattr(obj, TAGS_ATTR, set())
 
-        super(_TagsForm, self).process(
-            formdata=formdata, obj=None, data=data, tags=tags, **kwargs
-        )
+        super().process(formdata=formdata, obj=None, data=data, tags=tags, **kwargs)
 
 
-class TagsExtension(object):
+class TagsExtension:
     """API for tags, installed as an application extension.
 
     It is also available in templates as `tags`.
     """
 
-    def __init__(self, app):
+    def __init__(self, app: Flask) -> None:
         app.extensions["tags"] = self
         app.add_template_global(self, "tags")
         app.register_blueprint(tags_bp)
@@ -100,10 +94,7 @@ class TagsExtension(object):
             ns = self.entity_default_ns(entity)
 
         field = TagsField(label=_l("Tags"), ns=ns)
-        if six.PY2:
-            cls = type(b"EntityNSTagsForm", (_TagsForm,), {b"tags": field})
-        else:
-            cls = type("EntityNSTagsForm", (_TagsForm,), {"tags": field})
+        cls = type("EntityNSTagsForm", (_TagsForm,), {"tags": field})
         return cls
 
     def get(self, ns, label=None):
@@ -120,8 +111,9 @@ class TagsExtension(object):
 
         return query.all()
 
-    def add(self, entity, tag=None, ns=None, label=None):
-        # type: (Entity, Tag, Any, Any) -> Tag
+    def add(
+        self, entity: Entity, tag: Tag = None, ns: Any = None, label: Any = None
+    ) -> Tag:
         if tag is None:
             assert None not in (ns, label)
             tag = self.get(ns, label)
