@@ -64,4 +64,4 @@
     return Abilian;
 }));
 
-require(['Abilian', 'domReady!'], function(Abilian){ Abilian.init(); });
\ No newline at end of file
+require(['Abilian', 'domReady!'], function(Abilian, doc){ Abilian.init(); });
