@@ -1,9 +1,8 @@
-# coding=utf-8
-
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
+from typing import Union
 
 import sqlalchemy as sa
+from flask import Flask
+from flask.ctx import RequestContext
 from flask.signals import request_started
 from pytest import mark
 from wtforms import Form, IntegerField, StringField
@@ -12,10 +11,9 @@ from wtforms import Form, IntegerField, StringField
 # noinspection PyUnresolvedReferences
 import abilian.web.forms  # noqa
 from abilian.core.entities import Entity
-from abilian.web.views import default_view
-
-from ..forms.widgets import EmailWidget, MainTableView, Panel, Row, \
+from abilian.web.forms.widgets import EmailWidget, MainTableView, Panel, Row, \
     SingleView, linkify_url, text2html
+from abilian.web.views import default_view
 
 
 class WidgetTestModel(Entity):
@@ -27,10 +25,10 @@ class WidgetTestModel(Entity):
     email = sa.Column(sa.Text)
 
     def __init__(self, *args, **kw):
-        Entity.__init__(self, *args, **kw)
+        super().__init__(*args, **kw)
         self._display_value_called = False
 
-    def display_value(self, attr):
+    def display_value(self, attr: str) -> Union[int, str]:
         self._display_value_called = True
         return getattr(self, attr)
 
@@ -41,14 +39,14 @@ class DummyForm(Form):
     email = StringField("email", view_widget=EmailWidget())
 
 
-def test_table_view(app, test_request_context):
+def test_table_view(app: Flask, test_request_context: RequestContext) -> None:
     @default_view(app, WidgetTestModel)
     @app.route("/dummy_view/<object_id>")
     def dummy_view(object_id):
         pass
 
     request_started.send(app)  # needed for deferJS tag
-    columns = ["name", "price"]
+    columns = [{"name": "name"}, {"name": "price"}]
     view = MainTableView(columns)
 
     model1 = WidgetTestModel(id=1, name="Renault Megane", price=10000)
@@ -62,12 +60,12 @@ def test_table_view(app, test_request_context):
     assert "10000" in res
 
 
-def test_single_view(test_request_context):
-    panels = [Panel("main", Row("name"), Row("price"), Row("email"))]
-    view = SingleView(DummyForm, *panels, view={"can_edit": False, "can_delete": False})
+def test_single_view(test_request_context: RequestContext) -> None:
     model = WidgetTestModel(name="Renault Megane", price=10000, email="joe@example.com")
+    panels = [Panel("main", Row("name"), Row("price"), Row("email"))]
     form = DummyForm(obj=model)
-    res = view.render(model, form)
+    view = SingleView(form, *panels, view={"can_edit": False, "can_delete": False})
+    res = view.render(model)
 
     assert "Renault Megane" in res
     assert "10000" in res
@@ -78,11 +76,11 @@ def test_single_view(test_request_context):
 @mark.skip
 def test_edit_view(app):
     with app.test_request_context():
-        panels = [Panel("main", Row("name"), Row("price"))]
-        view = SingleView(DummyForm, *panels)
         model = WidgetTestModel(name="Renault Megane", price=10000)
+        panels = [Panel("main", Row("name"), Row("price"))]
         form = DummyForm(obj=model)
-        res = view.render_form(form)
+        view = SingleView(form, *panels)
+        res = view.render_form()
 
         assert model._display_value_called
         assert "Renault Megane" in res
@@ -95,33 +93,33 @@ EXPECTED = (
 )
 
 
-def test_http():
+def test_http() -> None:
     value = "http://example.com"
     result = linkify_url(value)
     assert result == EXPECTED
 
 
-def test_no_http():
+def test_no_http() -> None:
     value = "example.com"
     result = linkify_url(value)
     assert result == EXPECTED
 
 
-def test1():
+def test1() -> None:
     result = text2html("a")
     assert result == "a"
 
 
-def test2():
+def test2() -> None:
     result = text2html("a\nb")
     assert str(result) == "<p>a</p>\n<p>b</p>"
 
 
-def test3():
+def test3() -> None:
     result = text2html("a\n\nb")
     assert str(result) == "<p>a</p>\n<p>b</p>"
 
 
-def test4():
+def test4() -> None:
     result = text2html("a\n<a>toto</a>")
     assert str(result) == "<p>a</p>\n<p>&lt;a&gt;toto&lt;/a&gt;</p>"
