@@ -1,20 +1,19 @@
-# coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import json
 import logging
 import time
 from datetime import timedelta
+from io import BufferedReader
+from pathlib import PosixPath
+from typing import Any, Dict, Optional
 from uuid import UUID, uuid1
 
 from celery import shared_task
 from flask import current_app
-from flask_login import AnonymousUserMixin
-from six import PY3, text_type
 
+from abilian.app import Application
 from abilian.core import signals
+from abilian.core.models.subjects import User
 from abilian.web import url_for
 
 from .views import bp as blueprint
@@ -33,7 +32,7 @@ CLEANUP_SCHEDULE_ID = __name__ + ".periodic_clean_upload_directory"
 DEFAULT_CLEANUP_SCHEDULE = {"task": CLEANUP_SCHEDULE_ID, "schedule": timedelta(hours=1)}
 
 
-def is_valid_handle(handle):
+def is_valid_handle(handle: str) -> bool:
     try:
         UUID(handle)
     except ValueError:
@@ -42,7 +41,7 @@ def is_valid_handle(handle):
     return True
 
 
-class FileUploadsExtension(object):
+class FileUploadsExtension:
     """API for Out-Of-Band file uploads.
 
     Allow to manage files in forms: file is uploaded to an upload url, a handle is
@@ -53,13 +52,13 @@ class FileUploadsExtension(object):
     A periodic task cleans the temporary repository.
     """
 
-    def __init__(self, app):
+    def __init__(self, app: Application) -> None:
         app.extensions["uploads"] = self
         app.add_template_global(self, "uploads")
         app.register_blueprint(blueprint)
         signals.register_js_api.connect(self._do_register_js_api)
 
-        self.config = {}
+        self.config: Dict[str, Any] = {}
         self.config.update(DEFAULT_CONFIG)
         self.config.update(app.config.get("FILE_UPLOADS", {}))
         app.config["FILE_UPLOADS"] = self.config
@@ -69,25 +68,25 @@ class FileUploadsExtension(object):
         if CLEANUP_SCHEDULE_ID not in CELERYBEAT_SCHEDULE:
             CELERYBEAT_SCHEDULE[CLEANUP_SCHEDULE_ID] = DEFAULT_CLEANUP_SCHEDULE
 
-        path = self.UPLOAD_DIR = app.DATA_DIR / "uploads"
+        path = self.UPLOAD_DIR = app.data_dir / "uploads"
         if not path.exists():
             path.mkdir(mode=0o775, parents=True)
 
         path.resolve()
 
-    def _do_register_js_api(self, sender):
+    def _do_register_js_api(self, sender: Application) -> None:
         app = sender
         js_api = app.js_api.setdefault("upload", {})
         js_api["newFileUrl"] = url_for("uploads.new_file")
 
-    def user_dir(self, user):
-        if isinstance(user, AnonymousUserMixin):
+    def user_dir(self, user: User) -> PosixPath:
+        if user.is_anonymous:
             user_id = "anonymous"
         else:
-            user_id = text_type(user.id)
+            user_id = str(user.id)
         return self.UPLOAD_DIR / user_id
 
-    def add_file(self, user, file_obj, **metadata):
+    def add_file(self, user: User, file_obj: BufferedReader, **metadata) -> str:
         """Add a new file.
 
         :returns: file handle
@@ -104,16 +103,14 @@ class FileUploadsExtension(object):
                 out.write(chunk)
 
         if metadata:
-            meta_file = user_dir / "{}.metadata".format(handle)
+            meta_file = user_dir / f"{handle}.metadata"
             with meta_file.open("wb") as out:
-                metadata_json = json.dumps(metadata, skipkeys=True)
-                if PY3:
-                    metadata_json = metadata_json.encode("ascii")
+                metadata_json = json.dumps(metadata, skipkeys=True).encode("ascii")
                 out.write(metadata_json)
 
         return handle
 
-    def get_file(self, user, handle):
+    def get_file(self, user: User, handle: str) -> Optional[PosixPath]:
         """Retrieve a file for a user.
 
         :returns: a :class:`pathlib.Path` instance to this file,
@@ -133,18 +130,18 @@ class FileUploadsExtension(object):
 
         return file_path
 
-    def get_metadata_file(self, user, handle):
+    def get_metadata_file(self, user: User, handle: str) -> Optional[PosixPath]:
         content = self.get_file(user, handle)
         if content is None:
             return None
 
-        metafile = content.parent / "{}.metadata".format(handle)
+        metafile = content.parent / f"{handle}.metadata"
         if not metafile.exists():
             return None
 
         return metafile
 
-    def get_metadata(self, user, handle):
+    def get_metadata(self, user: User, handle: str) -> Dict[str, str]:
         metafile = self.get_metadata_file(user, handle)
         if metafile is None:
             return {}
@@ -152,7 +149,7 @@ class FileUploadsExtension(object):
         try:
             with metafile.open("rb") as in_:
                 meta = json.load(in_)
-        except BaseException:
+        except Exception:
             meta = {}
 
         return meta
@@ -164,7 +161,7 @@ class FileUploadsExtension(object):
             if file_path is not None:
                 try:
                     file_path.unlink()
-                except BaseException:
+                except Exception:
                     logger.exception("Error during remove file")
 
     def clear_stalled_files(self):
