@@ -1,17 +1,6 @@
-# coding=utf-8
-from __future__ import absolute_import, division, print_function
-
 from .base import JSONView, View
-from .object import (
-    BaseObjectView,
-    JSONBaseSearch,
-    JSONModelSearch,
-    JSONWhooshSearch,
-    ObjectCreate,
-    ObjectDelete,
-    ObjectEdit,
-    ObjectView,
-)
+from .object import BaseObjectView, JSONBaseSearch, JSONModelSearch, \
+    JSONWhooshSearch, ObjectCreate, ObjectDelete, ObjectEdit, ObjectView
 from .registry import Registry, default_view
 
 __all__ = (
