@@ -1,16 +1,12 @@
-# coding=utf-8
 """Class based views."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import logging
+from typing import Dict
 
 import sqlalchemy as sa
 import sqlalchemy.exc
 import sqlalchemy.orm
 from flask import current_app, flash, g, redirect, render_template, request, \
     url_for
-from six import text_type
 from werkzeug.exceptions import BadRequest, NotFound
 
 from abilian.core.entities import ValidationError
@@ -53,7 +49,7 @@ class BaseObjectView(View):
     base_template = "base.html"
 
     def __init__(self, Model=None, pk=None, base_template=None, *args, **kwargs):
-        View.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
         cls = self.__class__
         self.pk = pk if pk is not None else cls.pk
         self.Model = Model if Model is not None else cls.Model
@@ -129,7 +125,7 @@ class ObjectView(BaseObjectView):
     form = None
 
     def __init__(self, Model=None, pk=None, Form=None, template=None, *args, **kwargs):
-        super(ObjectView, self).__init__(Model, pk, *args, **kwargs)
+        super().__init__(Model, pk, *args, **kwargs)
         cls = self.__class__
         self.Form = Form if Form is not None else cls.Form
         self.template = template if template is not None else cls.template
@@ -138,7 +134,7 @@ class ObjectView(BaseObjectView):
         """
         :attr:`form` is initialized here. See also :meth:`View.prepare_args`.
         """
-        args, kwargs = super(ObjectView, self).prepare_args(args, kwargs)
+        args, kwargs = super().prepare_args(args, kwargs)
         form_kwargs = self.get_form_kwargs()
         self.form = self.Form(**form_kwargs)
         return args, kwargs
@@ -158,7 +154,7 @@ class ObjectView(BaseObjectView):
     @property
     def template_kwargs(self):
         """Provides :attr:`form` to templates."""
-        kw = super(ObjectView, self).template_kwargs
+        kw = super().template_kwargs
         kw["form"] = self.form
         return kw
 
@@ -218,14 +214,14 @@ class ObjectEdit(ObjectView):
         view_endpoint=None,
         message_success=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
-        ObjectView.__init__(self, Model, pk, Form, template=template, *args, **kwargs)
+        super().__init__(Model, pk, Form, template=template, *args, **kwargs)
         if view_endpoint is not None:
             self.view_endpoint = view_endpoint
 
         if not self.view_endpoint:
-            self.view_endpoint = ".{}_view".format(self.Model.__name__)
+            self.view_endpoint = f".{self.Model.__name__}_view"
 
         if message_success:
             self._message_success = message_success
@@ -242,7 +238,7 @@ class ObjectEdit(ObjectView):
         return self.post()
 
     def prepare_args(self, args, kwargs):
-        args, kwargs = super(ObjectEdit, self).prepare_args(args, kwargs)
+        args, kwargs = super().prepare_args(args, kwargs)
         self._buttons = self.get_form_buttons(*args, **kwargs)
         self.data = request.form
         return args, kwargs
@@ -266,19 +262,17 @@ class ObjectEdit(ObjectView):
         return redirect(self.view_url())
 
     def message_success(self):
-        return text_type(self._message_success)
+        return str(self._message_success)
 
     # actions
     def handle_action(self, action):
         for button in self._buttons:
             if action == button.name:
                 if not button.available({"view": self}):
-                    raise ValueError(
-                        'Action "{}" not available' "".format(action.encode("utf-8"))
-                    )
+                    raise ValueError(f'Action "{action.encode("utf-8")}" not available')
                 break
         else:
-            raise ValueError('Unknown action: "{}"'.format(action.encode("utf-8")))
+            raise ValueError(f'Unknown action: "{action.encode("utf-8")}"')
 
         self.action = action
         self.button = button
@@ -321,12 +315,10 @@ class ObjectEdit(ObjectView):
             del form.image
             store_image(image)
         """
-        pass
 
     def after_populate_obj(self):
         """Called after `self.obj` values have been updated, and `self.obj`
         attached to an ORM session."""
-        pass
 
     def handle_commit_exception(self, exc):
         """Hook point to handle exception that may happen during commit.
@@ -459,14 +451,14 @@ class ObjectCreate(ObjectEdit):
         if chain_create_allowed is not None:
             self.chain_create_allowed = bool(chain_create_allowed)
 
-        ObjectEdit.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def prepare_args(self, args, kwargs):
         # we must ensure that no flush() occurs and that obj is not registered
         # in session (to prevent accidental insert of an incomplete object)
         session = db.session()
         with session.no_autoflush:
-            args, kwargs = super(ObjectCreate, self).prepare_args(args, kwargs)
+            args, kwargs = super().prepare_args(args, kwargs)
 
         try:
             session.expunge(self.obj)
@@ -481,7 +473,7 @@ class ObjectCreate(ObjectEdit):
         return args, kwargs
 
     def get_form_kwargs(self):
-        kw = super(ObjectCreate, self).get_form_kwargs()
+        kw = super().get_form_kwargs()
         if request.method == "GET":
             # when GET allow form prefill instead of empty/current object data
             # FIXME: filter allowed parameters on given a field flags (could be
@@ -564,7 +556,7 @@ class JSONBaseSearch(JSONView):
         minimum_input_length = kwargs.pop(
             "minimum_input_length", self.minimum_input_length
         )
-        super(JSONBaseSearch, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.Model = Model
         self.minimum_input_length = minimum_input_length
 
@@ -573,9 +565,9 @@ class JSONBaseSearch(JSONView):
         kwargs["q"] = kwargs.get("q", "").replace("%", " ").lower()
         return args, kwargs
 
-    def data(self, q, *args, **kwargs):
+    def data(self, q, *args, **kwargs) -> Dict:
         if self.minimum_input_length and len(q) < self.minimum_input_length:
-            msg = "Minimum query length is {:d}".format(self.minimum_input_length)
+            msg = f"Minimum query length is {self.minimum_input_length:d}"
             raise BadRequest(msg)
 
         results = []
@@ -660,9 +652,7 @@ class JSONWhooshSearch(JSONBaseSearch):
                     results.sort(key=lambda it: it.fields().get(itemkey))
         except Exception:
             if itemkey is not None:
-                msg = "we could not sort whoosh results on fields' key {}.".format(
-                    itemkey
-                )
+                msg = f"we could not sort whoosh results on fields' key {itemkey}."
                 logger.warning(msg)
 
         return results
